'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

var toString = Object.prototype.toString;

var kindOf = function kindOf(val) {
  if (val === void 0) return 'undefined';
  if (val === null) return 'null';

  var type = typeof val;
  if (type === 'boolean') return 'boolean';
  if (type === 'string') return 'string';
  if (type === 'number') return 'number';
  if (type === 'symbol') return 'symbol';
  if (type === 'function') {
    return isGeneratorFn(val) ? 'generatorfunction' : 'function';
  }

  if (isArray(val)) return 'array';
  if (isBuffer(val)) return 'buffer';
  if (isArguments(val)) return 'arguments';
  if (isDate(val)) return 'date';
  if (isError(val)) return 'error';
  if (isRegexp(val)) return 'regexp';

  switch (ctorName(val)) {
    case 'Symbol': return 'symbol';
    case 'Promise': return 'promise';

    // Set, Map, WeakSet, WeakMap
    case 'WeakMap': return 'weakmap';
    case 'WeakSet': return 'weakset';
    case 'Map': return 'map';
    case 'Set': return 'set';

    // 8-bit typed arrays
    case 'Int8Array': return 'int8array';
    case 'Uint8Array': return 'uint8array';
    case 'Uint8ClampedArray': return 'uint8clampedarray';

    // 16-bit typed arrays
    case 'Int16Array': return 'int16array';
    case 'Uint16Array': return 'uint16array';

    // 32-bit typed arrays
    case 'Int32Array': return 'int32array';
    case 'Uint32Array': return 'uint32array';
    case 'Float32Array': return 'float32array';
    case 'Float64Array': return 'float64array';
  }

  if (isGeneratorObj(val)) {
    return 'generator';
  }

  // Non-plain objects
  type = toString.call(val);
  switch (type) {
    case '[object Object]': return 'object';
    // iterators
    case '[object Map Iterator]': return 'mapiterator';
    case '[object Set Iterator]': return 'setiterator';
    case '[object String Iterator]': return 'stringiterator';
    case '[object Array Iterator]': return 'arrayiterator';
  }

  // other
  return type.slice(8, -1).toLowerCase().replace(/\s/g, '');
};

function ctorName(val) {
  return typeof val.constructor === 'function' ? val.constructor.name : null;
}

function isArray(val) {
  if (Array.isArray) return Array.isArray(val);
  return val instanceof Array;
}

function isError(val) {
  return val instanceof Error || (typeof val.message === 'string' && val.constructor && typeof val.constructor.stackTraceLimit === 'number');
}

function isDate(val) {
  if (val instanceof Date) return true;
  return typeof val.toDateString === 'function'
    && typeof val.getDate === 'function'
    && typeof val.setDate === 'function';
}

function isRegexp(val) {
  if (val instanceof RegExp) return true;
  return typeof val.flags === 'string'
    && typeof val.ignoreCase === 'boolean'
    && typeof val.multiline === 'boolean'
    && typeof val.global === 'boolean';
}

function isGeneratorFn(name, val) {
  return ctorName(name) === 'GeneratorFunction';
}

function isGeneratorObj(val) {
  return typeof val.throw === 'function'
    && typeof val.return === 'function'
    && typeof val.next === 'function';
}

function isArguments(val) {
  try {
    if (typeof val.length === 'number' && typeof val.callee === 'function') {
      return true;
    }
  } catch (err) {
    if (err.message.indexOf('callee') !== -1) {
      return true;
    }
  }
  return false;
}

/**
 * If you need to support Safari 5-7 (8-10 yr-old browser),
 * take a look at https://github.com/feross/is-buffer
 */

function isBuffer(val) {
  if (val.constructor && typeof val.constructor.isBuffer === 'function') {
    return val.constructor.isBuffer(val);
  }
  return false;
}

const valueOf = Symbol.prototype.valueOf;


function clone(val, deep) {
  switch (kindOf(val)) {
    case 'array':
      return val.slice();
    case 'object':
      return Object.assign({}, val);
    case 'date':
      return new val.constructor(Number(val));
    case 'map':
      return new Map(val);
    case 'set':
      return new Set(val);
    case 'buffer':
      return cloneBuffer(val);
    case 'symbol':
      return cloneSymbol(val);
    case 'arraybuffer':
      return cloneArrayBuffer(val);
    case 'float32array':
    case 'float64array':
    case 'int16array':
    case 'int32array':
    case 'int8array':
    case 'uint16array':
    case 'uint32array':
    case 'uint8clampedarray':
    case 'uint8array':
      return cloneTypedArray(val);
    case 'regexp':
      return cloneRegExp(val);
    case 'error':
      return Object.create(val);
    default: {
      return val;
    }
  }
}

function cloneRegExp(val) {
  const flags = val.flags !== void 0 ? val.flags : (/\w+$/.exec(val) || void 0);
  const re = new val.constructor(val.source, flags);
  re.lastIndex = val.lastIndex;
  return re;
}

function cloneArrayBuffer(val) {
  const res = new val.constructor(val.byteLength);
  new Uint8Array(res).set(new Uint8Array(val));
  return res;
}

function cloneTypedArray(val, deep) {
  return new val.constructor(val.buffer, val.byteOffset, val.length);
}

function cloneBuffer(val) {
  const len = val.length;
  const buf = Buffer.allocUnsafe ? Buffer.allocUnsafe(len) : Buffer.from(len);
  val.copy(buf);
  return buf;
}

function cloneSymbol(val) {
  return valueOf ? Object(valueOf.call(val)) : {};
}

/**
 * Expose `clone`
 */

var shallowClone = clone;

/*!
 * isobject <https://github.com/jonschlinkert/isobject>
 *
 * Copyright (c) 2014-2017, Jon Schlinkert.
 * Released under the MIT License.
 */

var isobject = function isObject(val) {
  return val != null && typeof val === 'object' && Array.isArray(val) === false;
};

function isObjectObject(o) {
  return isobject(o) === true
    && Object.prototype.toString.call(o) === '[object Object]';
}

var isPlainObject = function isPlainObject(o) {
  var ctor,prot;

  if (isObjectObject(o) === false) return false;

  // If has modified constructor
  ctor = o.constructor;
  if (typeof ctor !== 'function') return false;

  // If has modified prototype
  prot = ctor.prototype;
  if (isObjectObject(prot) === false) return false;

  // If constructor does not have an Object-specific method
  if (prot.hasOwnProperty('isPrototypeOf') === false) {
    return false;
  }

  // Most likely a plain Object
  return true;
};

/**
 * Module dependenices
 */





function cloneDeep(val, instanceClone) {
  switch (kindOf(val)) {
    case 'object':
      return cloneObjectDeep(val, instanceClone);
    case 'array':
      return cloneArrayDeep(val, instanceClone);
    default: {
      return shallowClone(val);
    }
  }
}

function cloneObjectDeep(val, instanceClone) {
  if (typeof instanceClone === 'function') {
    return instanceClone(val);
  }
  if (instanceClone || isPlainObject(val)) {
    const res = new val.constructor();
    for (let key in val) {
      res[key] = cloneDeep(val[key], instanceClone);
    }
    return res;
  }
  return val;
}

function cloneArrayDeep(val, instanceClone) {
  const res = new val.constructor(val.length);
  for (let i = 0; i < val.length; i++) {
    res[i] = cloneDeep(val[i], instanceClone);
  }
  return res;
}

/**
 * Expose `cloneDeep`
 */

var cloneDeep_1 = cloneDeep;

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = "@font-face{font-family:next-font;src:url(../fonts/next-font.eot?-9scffx);src:url(../fonts/next-font.eot?#iefix-9scffx) format('embedded-opentype'),url(../fonts/next-font.woff?-9scffx) format('woff'),url(../fonts/next-font.ttf?-9scffx) format('truetype'),url(../fonts/next-font.svg?-9scffx#next-font) format('svg');font-weight:400;font-style:normal}@font-face{font-family:\"Cisco Sans Extra Light\";src:url(../fonts/cisco/ciscosansextralight-webfont.eot);src:url(../fonts/cisco/ciscosansextralight-webfont.eot?#iefix) format('embedded-opentype'),url(../fonts/cisco/ciscosansextralight-webfont.woff) format('woff'),url(../fonts/cisco/ciscosansextralight-webfont.ttf) format('truetype'),url(../fonts/cisco/ciscosansextralight-webfont.svg#CiscoSansExtraLight) format('svg');font-weight:400;font-style:normal}@font-face{font-family:\"Cisco Sans Reg\";src:url(../fonts/cisco/ciscosansregular-webfont.eot);src:url(../fonts/cisco/ciscosansregular-webfont.eot?#iefix) format('embedded-opentype'),url(../fonts/cisco/ciscosansregular-webfont.woff) format('woff'),url(../fonts/cisco/ciscosansregular-webfont.ttf) format('truetype'),url(../fonts/cisco/ciscosansregular-webfont.svg#CiscoSansReg) format('svg');font-weight:400;font-style:normal}[class*=\" n-icon-\"],[class^=n-icon-]{font-family:next-font;speak:none;font-style:normal;font-weight:400;font-variant:normal;text-transform:none;line-height:1;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.n-icon-hostgroupbg:before{content:\"\\e64c\"}.n-icon-hostgroup:before{content:\"\\e64d\"}.n-icon-wirelesshost:before{content:\"\\e64e\"}.n-icon-wirelesshostwithborder-30:before{content:\"\\e64f\"}.n-icon-firewallwithboder:before{content:\"\\e649\"}.n-icon-unknowndevicewithborder:before{content:\"\\e64a\"}.n-icon-unlinkwithborder:before{content:\"\\e64b\"}.n-icon-unlinked:before{content:\"\\e646\"}.n-icon-firewall:before{content:\"\\e647\"}.n-icon-firewallbg:before{content:\"\\e648\"}.n-icon-accesspointwithborder:before{content:\"\\e637\"}.n-icon-camerawithborder:before{content:\"\\e638\"}.n-icon-cloudwithborder:before{content:\"\\e639\"}.n-icon-grouplwithborder:before{content:\"\\e63a\"}.n-icon-groupmwithborder:before{content:\"\\e63b\"}.n-icon-groupswithborder:before{content:\"\\e63c\"}.n-icon-hostwithborder:before{content:\"\\e63d\"}.n-icon-ipphonewithborder:before{content:\"\\e63e\"}.n-icon-nexus5000withborder:before{content:\"\\e63f\"}.n-icon-phonewithborder:before{content:\"\\e640\"}.n-icon-routerwithborder:before{content:\"\\e641\"}.n-icon-serverwithborder:before{content:\"\\e642\"}.n-icon-switchwithborder:before{content:\"\\e643\"}.n-icon-unknowndeviceswithborder:before{content:\"\\e644\"}.n-icon-wlcwithborder:before{content:\"\\e645\"}.n-icon-co-worker:before{content:\"\\e634\"}.n-icon-layer:before{content:\"\\e635\"}.n-icon-layout:before{content:\"\\e636\"}.n-icon-cloud:before{content:\"\\e633\"}.n-icon-de-aggregation:before{content:\"\\e632\"}.n-icon-expand:before{content:\"\\e62d\"}.n-icon-collapse:before{content:\"\\e62e\"}.n-icon-groupsbg:before{content:\"\\e62f\"}.n-icon-groupmbg:before{content:\"\\e630\"}.n-icon-grouplbg:before{content:\"\\e631\"}.n-icon-fullscreen:before{content:\"\\e62c\"}.n-icon-movemode:before{content:\"\\e62b\"}.n-icon-RCV:before{content:\"\\e62a\"}.n-icon-PGN:before{content:\"\\e60b\"}.n-icon-co-edit:before{content:\"\\e60c\"}.n-icon-wlc:before{content:\"\\e60f\"}.n-icon-wlcbg:before{content:\"\\e610\"}.n-icon-unknownbg:before{content:\"\\e611\"}.n-icon-unknown:before{content:\"\\e612\"}.n-icon-switch:before{content:\"\\e618\"}.n-icon-switchbg:before{content:\"\\e619\"}.n-icon-serverbg:before{content:\"\\e61a\"}.n-icon-server:before{content:\"\\e61b\"}.n-icon-router:before{content:\"\\e61c\"}.n-icon-routerbg:before{content:\"\\e61d\"}.n-icon-phone:before{content:\"\\e61e\"}.n-icon-phonebg:before{content:\"\\e61f\"}.n-icon-nexus5000:before{content:\"\\e620\"}.n-icon-nexus5000bg:before{content:\"\\e621\"}.n-icon-ipphone:before{content:\"\\e622\"}.n-icon-ipphonebg:before{content:\"\\e623\"}.n-icon-host:before{content:\"\\e624\"}.n-icon-hostbg:before{content:\"\\e625\"}.n-icon-camera:before{content:\"\\e626\"}.n-icon-camerabg:before{content:\"\\e627\"}.n-icon-accesspoint:before{content:\"\\e628\"}.n-icon-accesspointbg:before{content:\"\\e629\"}.n-icon-groups:before{content:\"\\e615\"}.n-icon-groupm2:before{content:\"\\e616\"}.n-icon-groupl:before{content:\"\\e617\"}.n-icon-zoomout-minus:before{content:\"\\e613\"}.n-icon-zoomin-plus:before{content:\"\\e614\"}.n-icon-zoomout:before{content:\"\\e606\"}.n-icon-zoomin:before{content:\"\\e607\"}.n-icon-zoombyselection:before{content:\"\\e608\"}.n-icon-viewsetting:before{content:\"\\e609\"}.n-icon-selectnode:before{content:\"\\e60a\"}.n-icon-fitstage:before{content:\"\\e60d\"}.n-icon-aggregation:before{content:\"\\e60e\"}.n-icon-interface:before{content:\"\\e600\"}.n-icon-router2:before{content:\"\\e601\"}.n-icon-openflow:before{content:\"\\e602\"}.n-icon-BMP:before{content:\"\\e603\"}.n-icon-BGP:before{content:\"\\e604\"}.n-icon-acl:before{content:\"\\e605\"}.n-topology.n-topology-blue{position:relative;overflow:hidden;background:#fff;-webkit-transition:background .6s;transition:background .6s;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-blue:focus{outline:0 none}.n-topology.n-topology-blue .n-topology-fit{-webkit-transition:all .6s linear!important;transition:all .6s linear!important}.n-topology.n-topology-blue .n-topology-fit .link,.n-topology.n-topology-blue .n-topology-fit .linkSet,.n-topology.n-topology-blue .n-topology-fit .node,.n-topology.n-topology-blue .n-topology-fit .nodeSet{-webkit-transition:all .9s linear!important;transition:all .9s linear!important}.n-topology.n-topology-blue.n-topology-loading .n-topology-nav,.n-topology.n-topology-blue.n-topology-loading svg{-webkit-filter:blur(5px);-moz-filter:blur(5px)}.n-topology.n-topology-blue svg{box-sizing:content-box;position:absolute;top:0;left:0;right:0;bottom:0}.n-topology.n-topology-blue text:empty{display:none}.n-topology.n-topology-blue g{pointer-events:all}.n-topology.n-topology-blue defs .bg{fill:#0386d2}.n-topology.n-topology-blue defs .stroke{stroke:#0386d2}.n-topology.n-topology-blue defs [fill*='#FFFFFF']{fill:#fff}.n-topology.n-topology-blue .n-svg{border:0;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-blue .fontIcon{font-family:next-font;fill:#0386d2;alignment-baseline:central;text-anchor:middle;speak:none;font-style:normal;font-weight:400;font-variant:normal;text-transform:none;line-height:1;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.n-topology.n-topology-blue text{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.n-topology.n-topology-blue .n-topology-icon .fontIcon{cursor:pointer}.n-topology.n-topology-blue .iconBG{fill:#fff}.n-topology.n-topology-blue .iconBGActive{fill:#0386d2}.n-topology.n-topology-blue .node:not(.node-selected) .selectedBG{display:none}.n-topology.n-topology-blue .node .selectedBG{fill:transparent;opacity:.8;stroke:#f2ad4e;stroke-width:3;pointer-events:none}.n-topology.n-topology-blue .node .dot{fill:#0386d2}.n-topology.n-topology-blue .node text.node-label{font-family:\"Cisco Sans Reg\";fill:#0386d2;pointer-events:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;font-size:11px}.n-topology.n-topology-blue .node.disable .node-label{fill:#ccc!important}.n-topology.n-topology-blue .node.disable .iconBG.iconBGActive,.n-topology.n-topology-blue .node.disable .showIcon .iconShape{fill:#ccc}.n-topology.n-topology-blue .link line,.n-topology.n-topology-blue .link path{stroke:#5bc1df;stroke-width:1px;fill:none;cursor:pointer}.n-topology.n-topology-blue .link line.link:hover,.n-topology.n-topology-blue .link path.link:hover{stroke:#26a1c5}.n-topology.n-topology-blue .link line.link_bg:hover~line{stroke:#26a1c5!important}.n-topology.n-topology-blue .link .link-label{font-family:\"Cisco Sans Reg\";fill:#0386d2;font-size:12px}.n-topology.n-topology-blue .link .source-abel,.n-topology.n-topology-blue .link .target-label{font-family:\"Cisco Sans Reg\";fill:#0386d2;opacity:.8;font-size:12px}.n-topology.n-topology-blue .link .disable-label{fill:#fff}.n-topology.n-topology-blue .link .disable-bg{fill:#ccc}.n-topology.n-topology-blue .link .link_bg{stroke:transparent}.n-topology.n-topology-blue .link.disable line,.n-topology.n-topology-blue .link.disable path{stroke:#ccc!important;stroke-width:1px}.n-topology.n-topology-blue .link.disable .link_bg{stroke:transparent!important}.n-topology.n-topology-blue .link.link-selected line,.n-topology.n-topology-blue .link.link-selected path{stroke:#ccc;stroke-width:2px}.n-topology.n-topology-blue .nodeset .selectedBG{fill:transparent;opacity:.8;stroke:#f2ad4e;stroke-width:3;pointer-events:none}.n-topology.n-topology-blue .nodeset .dot{fill:#fff;stroke:#0386d2;stroke-width:1}.n-topology.n-topology-blue .nodeset .icon{cursor:pointer}.n-topology.n-topology-blue .nodeset .bg{fill:#0386d2;pointer-events:none}.n-topology.n-topology-blue .nodeset text.node-label{font-family:\"Cisco Sans Reg\";fill:#0386d2;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;pointer-events:none}.n-topology.n-topology-blue .nodeset.disable{opacity:.3;stroke:#ccc}.n-topology.n-topology-blue .nodeset .iconBG,.n-topology.n-topology-blue .nodeset .iconBGActive{fill:#fff}.n-topology.n-topology-blue .nodeset .iconBGActive~.iconShape{display:block!important}.n-topology.n-topology-blue .nodeset .indicator .iconBG{fill:#fff}.n-topology.n-topology-blue .nodeset .indicator .iconBG:hover{fill:#0386d2}.n-topology.n-topology-blue .nodeset .indicator .iconShape{fill:#0266a0}.n-topology.n-topology-blue .group .bg{opacity:.6;stroke-width:10px;stroke-linejoin:round}.n-topology.n-topology-blue .group .groupLabel{cursor:pointer;font-size:18px;font-family:\"Cisco Sans Reg\";text-anchor:middle;alignment-baseline:inherit}.n-topology.n-topology-blue .group .fontIcon.iconShape{fill:#9BB150}.n-topology.n-topology-blue .group .nodeSetGroupLabel{cursor:pointer;font-size:18px;font-family:\"Cisco Sans Reg\";alignment-baseline:inherit;fill:#9BB150}.n-topology.n-topology-blue .group .groupLabel:hover~.bg{opacity:.7}.n-topology.n-topology-blue .group.aggregationGroup .bg{stroke-width:10px;stroke-linejoin:round;fill:#9BB150;stroke:#9BB150;pointer-events:none;opacity:0;-webkit-transition:opacity .3s linear;transition:opacity .3s linear}.n-topology.n-topology-blue .group.aggregationGroup.fade-active-item{opacity:1}.n-topology.n-topology-blue .group.aggregationGroup.fade-active-item .bg{opacity:.5}.n-topology.n-topology-blue .link-set-bg{stroke:#5bc1df;stroke-width:2px}.n-topology.n-topology-blue .link-set-circle{fill:#0386d2;stroke:#0386d2;stroke-width:16px;stroke-linejoin:round}.n-topology.n-topology-blue .link-set-text{font-family:\"Cisco Sans Reg\";fill:#fff;text-anchor:middle;dominant-baseline:central;font-size:12px;pointer-events:none}.n-topology.n-topology-blue .link-set.disable .link-set-bg{stroke:#ccc}.n-topology.n-topology-blue .link-set.disable .link-set-circle{fill:#ccc;stroke:#ccc}@media screen and (-webkit-min-device-pixel-ratio:0){.n-topology.n-topology-blue .link-set-circle,.n-topology.n-topology-blue ::i-block-chrome{stroke-width:8px!important}}.n-topology.n-topology-blue .mapPath{fill:#d6effe;stroke:#ade0fe;stroke-width:1;opacity:.5;pointer-events:none}.n-topology.n-topology-blue .mapBoundary{fill:none;stroke:#ade0fe;stroke-width:1;pointer-events:none}.n-topology.n-topology-blue .selectionRect{stroke:#0386d2;fill:#0386d2;fill-opacity:.1;pointer-events:none}.n-topology.n-topology-blue-setting{max-width:none!important}.n-topology.n-topology-blue .aggregationGroup .aggregationText{fill:#0386d2;font-size:12px}.n-topology.n-topology-blue .aggregationGroup .aggregationRect{fill:#0386d2;opacity:.2;stroke:#0386d2;stroke-width:3;stroke-linejoin:round;pointer-events:none}.n-topology.n-topology-blue .layer>*{transition:opacity .6s}.n-topology.n-topology-blue .layer.fade-layer>:not(.fade-highlight-item):not(.fade-active-item),.n-topology.n-topology-blue.fade-active-priority.fade-active-occur .layer.fade-layer>.fade-highlight-item:not(.fade-active-item),.n-topology.n-topology-blue.fade-active-priority.fade-active-occur.fade-all .layer>.fade-highlight-item:not(.fade-active-item),.n-topology.n-topology-blue.fade-all .layer>:not(.fade-highlight-item):not(.fade-active-item){opacity:.2}.n-topology.n-topology-blue .n-topology-nav{position:absolute;top:0;left:8px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-blue .n-topology-nav li{list-style:none;padding:0}.n-topology.n-topology-blue .n-topology-nav ul{padding:0;margin:0}.n-topology.n-topology-blue .n-topology-nav span{-webkit-transition:all .6s;transition:all .6s}.n-topology.n-topology-blue .n-topology-nav>ul{padding:0;margin-top:30px;width:32px}.n-topology.n-topology-blue .n-topology-nav>ul>li{display:inline-block;list-style:none;width:25px;margin-top:5px;-webkit-transition:all .6s;transition:all .6s}.n-topology.n-topology-blue .n-topology-nav-mode{padding:0;position:relative;width:25px}.n-topology.n-topology-blue .n-topology-nav-mode li{width:25px;height:25px;line-height:30px;display:inline-block;text-align:center;cursor:pointer;-webkit-transition:all .6s;transition:all .6s;background:#eaeaea;margin-top:-2px}.n-topology.n-topology-blue .n-topology-nav-mode li:hover span{color:#0386d2}.n-topology.n-topology-blue .n-topology-nav-mode span{color:#999;display:inline-block;font-size:18px}.n-topology.n-topology-blue .n-topology-nav-mode-selected{background:#0386d2!important}.n-topology.n-topology-blue .n-topology-nav-mode-selected span{color:#fff}.n-topology.n-topology-blue .n-topology-nav-mode-selected:hover{background:#0386d2!important}.n-topology.n-topology-blue .n-topology-nav-mode-selected:hover span{color:#fff!important}.n-topology.n-topology-blue .n-topology-nav-zoom{position:relative;height:51px;margin-top:10px!important}.n-topology.n-topology-blue .n-topology-nav-zoom>span{display:inline-block;position:absolute;text-align:center;font-size:25px;color:#999;background:#eaeaea}.n-topology.n-topology-blue .n-topology-nav-zoom-in{top:0;left:0;cursor:pointer}.n-topology.n-topology-blue .n-topology-nav-zoom-in:hover{color:gray;background:#d8d8d8}.n-topology.n-topology-blue .n-topology-nav-zoom-out{top:25px;left:0;cursor:pointer}.n-topology.n-topology-blue .n-topology-nav-zoom-out:hover{color:gray;background:#d8d8d8}.n-topology.n-topology-blue .n-topology-nav-zoom-selection{cursor:pointer;text-align:center;font-size:22px;color:#999}.n-topology.n-topology-blue .n-topology-nav-zoom-selection:hover{color:#4d4d4d}.n-topology.n-topology-blue .n-topology-nav-zoom-selection-selected{color:#3fb7fc}.n-topology.n-topology-blue .n-topology-nav-fit{cursor:pointer;text-align:center;font-size:22px;color:#999}.n-topology.n-topology-blue .n-topology-nav-fit:hover{color:#4d4d4d}.n-topology.n-topology-blue .n-topology-nav-agr{cursor:pointer;line-height:24px;text-align:center;font-size:20px;height:24px;color:#999;display:none}.n-topology.n-topology-blue .n-topology-nav-agr:hover{color:#4d4d4d}@-webkit-keyframes agr-icon-ani{0%{-webkit-transform:rotate(0deg)}100%{-webkit-transform:rotate(360deg)}}.n-topology.n-topology-blue .n-topology-nav .agr-icon{-webkit-animation-duration:3s;-webkit-animation-name:agr-icon-ani;-webkit-animation-iteration-count:infinite;-webkit-animation-direction:normal;-webkit-animation-timing-function:linear;-webkit-transition:0 none;color:#0396eb}.n-topology.n-topology-blue .n-topology-nav .agr-text{font-size:10px;color:#eaeaea;position:absolute;left:10px;margin-top:-1px;height:12px}.n-topology.n-topology-blue .n-topology-nav-full{cursor:pointer;text-align:center;font-size:18px;color:#999}.n-topology.n-topology-blue .n-topology-nav-full:hover{color:#4d4d4d}.n-topology.n-topology-blue .n-topology-nav-setting{cursor:pointer;text-align:center;color:#999;line-height:1;-webkit-transition:none 0!important;transition:none 0!important}.n-topology.n-topology-blue .n-topology-nav-setting:hover{opacity:1;color:#0396eb}.n-topology.n-topology-blue .n-topology-nav-setting-icon{font-size:20px}.n-topology.n-topology-blue .n-topology-nav-setting-icon-selected{color:#0396eb}.n-topology.n-topology-blue .n-topology-loading{overflow:hidden;position:absolute;top:0;bottom:0;left:0;right:0;height:100%;width:100%;display:none}.n-topology.n-topology-blue .n-topology-loading ul{position:absolute;left:calc(49.3%);top:calc(45.8%);display:inline-block;text-indent:2.8em}.n-topology.n-topology-blue .n-topology-loading ul li:after,.n-topology.n-topology-blue .n-topology-loading ul:after{width:1.4em;height:1.4em;border-radius:100%;content:\"\";display:block}.n-topology.n-topology-blue .n-topology-loading ul:after{position:absolute;top:2.8em}.n-topology.n-topology-blue .n-topology-loading li{position:absolute;padding-bottom:5.6em;top:0;left:0;list-style:none}.n-topology.n-topology-blue .n-topology-loading li:after{background:#0386d2}.n-topology.n-topology-blue .n-topology-loading li:nth-child(1){-webkit-transform:rotate(0deg);-webkit-animation-delay:.125s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(1):after{-webkit-animation-delay:.125s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(2){-webkit-transform:rotate(36deg);-webkit-animation-delay:.25s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(2):after{-webkit-animation-delay:.25s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(3){-webkit-transform:rotate(72deg);-webkit-animation-delay:.375s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(3):after{-webkit-animation-delay:.375s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(4){-webkit-transform:rotate(108deg);-webkit-animation-delay:.5s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(4):after{-webkit-animation-delay:.5s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(5){-webkit-transform:rotate(144deg);-webkit-animation-delay:.625s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(5):after{-webkit-animation-delay:.625s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(6){-webkit-transform:rotate(180deg);-webkit-animation-delay:.75s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(6):after{-webkit-animation-delay:.75s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(7){-webkit-transform:rotate(216deg);-webkit-animation-delay:.875s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(7):after{-webkit-animation-delay:.875s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(8){-webkit-transform:rotate(252deg);-webkit-animation-delay:1s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(8):after{-webkit-animation-delay:1s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(9){-webkit-transform:rotate(288deg);-webkit-animation-delay:1.125s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(9):after{-webkit-animation-delay:1.125s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(10){-webkit-transform:rotate(324deg);-webkit-animation-delay:1.25s}.n-topology.n-topology-blue .n-topology-loading li:nth-child(10):after{-webkit-animation-delay:1.25s}.n-topology.n-topology-blue .n-topology-loading li{-webkit-animation:dotAnimation 2.5s infinite}@-webkit-keyframes dotAnimation{0%,100%,55%{padding:0 0 5.6em}5%,50%{padding:2.8em 0}}.n-topology.n-topology-blue .n-topology-loading li:after{-webkit-animation:dotAnimationTwo 2.5s infinite}@-webkit-keyframes dotAnimationTwo{0%,100%,55%{opacity:1;-webkit-transform:scale(1)}5%,50%{opacity:.5;-webkit-transform:scale(0.5)}}.n-topology.n-topology-dark{position:relative;overflow:hidden;background:#000;-webkit-transition:background .6s;transition:background .6s;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-dark:focus{outline:0 none}.n-topology.n-topology-dark .n-topology-fit{-webkit-transition:all .6s linear!important;transition:all .6s linear!important}.n-topology.n-topology-dark .n-topology-fit .link,.n-topology.n-topology-dark .n-topology-fit .linkSet,.n-topology.n-topology-dark .n-topology-fit .node,.n-topology.n-topology-dark .n-topology-fit .nodeSet{-webkit-transition:all .9s linear!important;transition:all .9s linear!important}.n-topology.n-topology-dark.n-topology-loading .n-topology-nav,.n-topology.n-topology-dark.n-topology-loading svg{-webkit-filter:blur(5px);-moz-filter:blur(5px)}.n-topology.n-topology-dark svg{box-sizing:content-box;position:absolute;top:0;left:0;right:0;bottom:0}.n-topology.n-topology-dark text:empty{display:none}.n-topology.n-topology-dark g{pointer-events:all}.n-topology.n-topology-dark defs .bg{fill:#00a9ff}.n-topology.n-topology-dark defs .stroke{stroke:#00a9ff}.n-topology.n-topology-dark defs [fill*='#FFFFFF']{fill:#000}.n-topology.n-topology-dark .n-svg{border:0;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-dark .fontIcon{font-family:next-font;fill:#00a9ff;alignment-baseline:central;text-anchor:middle;speak:none;font-style:normal;font-weight:400;font-variant:normal;text-transform:none;line-height:1;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.n-topology.n-topology-dark text{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.n-topology.n-topology-dark .n-topology-icon .fontIcon{cursor:pointer}.n-topology.n-topology-dark .iconBG{fill:#000}.n-topology.n-topology-dark .iconBGActive{fill:#00a9ff}.n-topology.n-topology-dark .node:not(.node-selected) .selectedBG{display:none}.n-topology.n-topology-dark .node .selectedBG{fill:transparent;opacity:.8;stroke:#f7931e;stroke-width:3;pointer-events:none}.n-topology.n-topology-dark .node .dot{fill:#00a9ff}.n-topology.n-topology-dark .node text.node-label{font-family:\"Cisco Sans Reg\";fill:#00a9ff;pointer-events:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;font-size:11px}.n-topology.n-topology-dark .node.disable .node-label{fill:#ccc!important}.n-topology.n-topology-dark .node.disable .iconBG.iconBGActive,.n-topology.n-topology-dark .node.disable .showIcon .iconShape{fill:#ccc}.n-topology.n-topology-dark .link line,.n-topology.n-topology-dark .link path{stroke:#09cadd;stroke-width:1px;fill:none;cursor:pointer}.n-topology.n-topology-dark .link line.link:hover,.n-topology.n-topology-dark .link path.link:hover{stroke:#068591}.n-topology.n-topology-dark .link line.link_bg:hover~line{stroke:#068591!important}.n-topology.n-topology-dark .link .link-label{font-family:\"Cisco Sans Reg\";fill:#00a9ff;font-size:12px}.n-topology.n-topology-dark .link .source-abel,.n-topology.n-topology-dark .link .target-label{font-family:\"Cisco Sans Reg\";fill:#00a9ff;opacity:.8;font-size:12px}.n-topology.n-topology-dark .link .disable-label{fill:#fff}.n-topology.n-topology-dark .link .disable-bg{fill:#ccc}.n-topology.n-topology-dark .link .link_bg{stroke:transparent}.n-topology.n-topology-dark .link.disable line,.n-topology.n-topology-dark .link.disable path{stroke:#ccc!important;stroke-width:1px}.n-topology.n-topology-dark .link.disable .link_bg{stroke:transparent!important}.n-topology.n-topology-dark .link.link-selected line,.n-topology.n-topology-dark .link.link-selected path{stroke:#ccc;stroke-width:2px}.n-topology.n-topology-dark .nodeset .selectedBG{fill:transparent;opacity:.8;stroke:#f7931e;stroke-width:3;pointer-events:none}.n-topology.n-topology-dark .nodeset .dot{fill:#000;stroke:#00a9ff;stroke-width:1}.n-topology.n-topology-dark .nodeset .icon{cursor:pointer}.n-topology.n-topology-dark .nodeset .bg{fill:#00a9ff;pointer-events:none}.n-topology.n-topology-dark .nodeset text.node-label{font-family:\"Cisco Sans Reg\";fill:#00a9ff;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;pointer-events:none}.n-topology.n-topology-dark .nodeset.disable{opacity:.3;stroke:#ccc}.n-topology.n-topology-dark .nodeset .iconBG,.n-topology.n-topology-dark .nodeset .iconBGActive{fill:#000}.n-topology.n-topology-dark .nodeset .iconBGActive~.iconShape{display:block!important}.n-topology.n-topology-dark .nodeset .indicator .iconBG{fill:#000}.n-topology.n-topology-dark .nodeset .indicator .iconBG:hover{fill:#00a9ff}.n-topology.n-topology-dark .nodeset .indicator .iconShape{fill:#0087cc}.n-topology.n-topology-dark .group .bg{opacity:.6;stroke-width:10px;stroke-linejoin:round}.n-topology.n-topology-dark .group .groupLabel{cursor:pointer;font-size:18px;font-family:\"Cisco Sans Reg\";text-anchor:middle;alignment-baseline:inherit}.n-topology.n-topology-dark .group .fontIcon.iconShape{fill:#9BB150}.n-topology.n-topology-dark .group .nodeSetGroupLabel{cursor:pointer;font-size:18px;font-family:\"Cisco Sans Reg\";alignment-baseline:inherit;fill:#9BB150}.n-topology.n-topology-dark .group .groupLabel:hover~.bg{opacity:.7}.n-topology.n-topology-dark .group.aggregationGroup .bg{stroke-width:10px;stroke-linejoin:round;fill:#9BB150;stroke:#9BB150;pointer-events:none;opacity:0;-webkit-transition:opacity .3s linear;transition:opacity .3s linear}.n-topology.n-topology-dark .group.aggregationGroup.fade-active-item{opacity:1}.n-topology.n-topology-dark .group.aggregationGroup.fade-active-item .bg{opacity:.5}.n-topology.n-topology-dark .link-set-bg{stroke:#09cadd;stroke-width:2px}.n-topology.n-topology-dark .link-set-circle{fill:#00a9ff;stroke:#00a9ff;stroke-width:16px;stroke-linejoin:round}.n-topology.n-topology-dark .link-set-text{font-family:\"Cisco Sans Reg\";fill:#000;text-anchor:middle;dominant-baseline:central;font-size:12px;pointer-events:none}.n-topology.n-topology-dark .link-set.disable .link-set-bg{stroke:#ccc}.n-topology.n-topology-dark .link-set.disable .link-set-circle{fill:#ccc;stroke:#ccc}@media screen and (-webkit-min-device-pixel-ratio:0){.n-topology.n-topology-dark .link-set-circle,.n-topology.n-topology-dark ::i-block-chrome{stroke-width:8px!important}}.n-topology.n-topology-dark .mapPath{fill:#fff;stroke:#d6f1ff;stroke-width:1;opacity:.5;pointer-events:none}.n-topology.n-topology-dark .mapBoundary{fill:none;stroke:#d6f1ff;stroke-width:1;pointer-events:none}.n-topology.n-topology-dark .selectionRect{stroke:#00a9ff;fill:#00a9ff;fill-opacity:.1;pointer-events:none}.n-topology.n-topology-dark-setting{max-width:none!important}.n-topology.n-topology-dark .aggregationGroup .aggregationText{fill:#00a9ff;font-size:12px}.n-topology.n-topology-dark .aggregationGroup .aggregationRect{fill:#00a9ff;opacity:.2;stroke:#00a9ff;stroke-width:3;stroke-linejoin:round;pointer-events:none}.n-topology.n-topology-dark .layer>*{transition:opacity .6s}.n-topology.n-topology-dark .layer.fade-layer>:not(.fade-highlight-item):not(.fade-active-item),.n-topology.n-topology-dark.fade-active-priority.fade-active-occur .layer.fade-layer>.fade-highlight-item:not(.fade-active-item),.n-topology.n-topology-dark.fade-active-priority.fade-active-occur.fade-all .layer>.fade-highlight-item:not(.fade-active-item),.n-topology.n-topology-dark.fade-all .layer>:not(.fade-highlight-item):not(.fade-active-item){opacity:.2}.n-topology.n-topology-dark .n-topology-nav{position:absolute;top:0;left:8px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-dark .n-topology-nav li{list-style:none;padding:0}.n-topology.n-topology-dark .n-topology-nav ul{padding:0;margin:0}.n-topology.n-topology-dark .n-topology-nav span{-webkit-transition:all .6s;transition:all .6s}.n-topology.n-topology-dark .n-topology-nav>ul{padding:0;margin-top:30px;width:32px}.n-topology.n-topology-dark .n-topology-nav>ul>li{display:inline-block;list-style:none;width:25px;margin-top:5px;-webkit-transition:all .6s;transition:all .6s}.n-topology.n-topology-dark .n-topology-nav-mode{padding:0;position:relative;width:25px}.n-topology.n-topology-dark .n-topology-nav-mode li{width:25px;height:25px;line-height:30px;display:inline-block;text-align:center;cursor:pointer;-webkit-transition:all .6s;transition:all .6s;background:#333;margin-top:-2px}.n-topology.n-topology-dark .n-topology-nav-mode li:hover span{color:#00a9ff}.n-topology.n-topology-dark .n-topology-nav-mode span{color:#666;display:inline-block;font-size:18px}.n-topology.n-topology-dark .n-topology-nav-mode-selected{background:#00a9ff!important}.n-topology.n-topology-dark .n-topology-nav-mode-selected span{color:#000}.n-topology.n-topology-dark .n-topology-nav-mode-selected:hover{background:#00a9ff!important}.n-topology.n-topology-dark .n-topology-nav-mode-selected:hover span{color:#000!important}.n-topology.n-topology-dark .n-topology-nav-zoom{position:relative;height:51px;margin-top:10px!important}.n-topology.n-topology-dark .n-topology-nav-zoom>span{display:inline-block;position:absolute;text-align:center;font-size:25px;color:#666;background:#333}.n-topology.n-topology-dark .n-topology-nav-zoom-in{top:0;left:0;cursor:pointer}.n-topology.n-topology-dark .n-topology-nav-zoom-in:hover{color:#b3b3b3;background:#4d4d4d}.n-topology.n-topology-dark .n-topology-nav-zoom-out{top:25px;left:0;cursor:pointer}.n-topology.n-topology-dark .n-topology-nav-zoom-out:hover{color:#b3b3b3;background:#4d4d4d}.n-topology.n-topology-dark .n-topology-nav-zoom-selection{cursor:pointer;text-align:center;font-size:22px;color:#666}.n-topology.n-topology-dark .n-topology-nav-zoom-selection:hover{color:#b3b3b3}.n-topology.n-topology-dark .n-topology-nav-zoom-selection-selected{color:#66cbff}.n-topology.n-topology-dark .n-topology-nav-fit{cursor:pointer;text-align:center;font-size:22px;color:#666}.n-topology.n-topology-dark .n-topology-nav-fit:hover{color:#b3b3b3}.n-topology.n-topology-dark .n-topology-nav-agr{cursor:pointer;line-height:24px;text-align:center;font-size:20px;height:24px;color:#666;display:none}.n-topology.n-topology-dark .n-topology-nav-agr:hover{color:#b3b3b3}@-webkit-keyframes agr-icon-ani{0%{-webkit-transform:rotate(0deg)}100%{-webkit-transform:rotate(360deg)}}.n-topology.n-topology-dark .n-topology-nav .agr-icon{-webkit-animation-duration:3s;-webkit-animation-name:agr-icon-ani;-webkit-animation-iteration-count:infinite;-webkit-animation-direction:normal;-webkit-animation-timing-function:linear;-webkit-transition:0 none;color:#1ab2ff}.n-topology.n-topology-dark .n-topology-nav .agr-text{font-size:10px;color:#333;position:absolute;left:10px;margin-top:-1px;height:12px}.n-topology.n-topology-dark .n-topology-nav-full{cursor:pointer;text-align:center;font-size:18px;color:#666}.n-topology.n-topology-dark .n-topology-nav-full:hover{color:#b3b3b3}.n-topology.n-topology-dark .n-topology-nav-setting{cursor:pointer;text-align:center;color:#666;line-height:1;-webkit-transition:none 0!important;transition:none 0!important}.n-topology.n-topology-dark .n-topology-nav-setting:hover{opacity:1;color:#1ab2ff}.n-topology.n-topology-dark .n-topology-nav-setting-icon{font-size:20px}.n-topology.n-topology-dark .n-topology-nav-setting-icon-selected{color:#1ab2ff}.n-topology.n-topology-dark .n-topology-loading{overflow:hidden;position:absolute;top:0;bottom:0;left:0;right:0;height:100%;width:100%;display:none}.n-topology.n-topology-dark .n-topology-loading ul{position:absolute;left:calc(49.3%);top:calc(45.8%);display:inline-block;text-indent:2.8em}.n-topology.n-topology-dark .n-topology-loading ul li:after,.n-topology.n-topology-dark .n-topology-loading ul:after{width:1.4em;height:1.4em;border-radius:100%;content:\"\";display:block}.n-topology.n-topology-dark .n-topology-loading ul:after{position:absolute;top:2.8em}.n-topology.n-topology-dark .n-topology-loading li{position:absolute;padding-bottom:5.6em;top:0;left:0;list-style:none}.n-topology.n-topology-dark .n-topology-loading li:after{background:#00a9ff}.n-topology.n-topology-dark .n-topology-loading li:nth-child(1){-webkit-transform:rotate(0deg);-webkit-animation-delay:.125s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(1):after{-webkit-animation-delay:.125s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(2){-webkit-transform:rotate(36deg);-webkit-animation-delay:.25s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(2):after{-webkit-animation-delay:.25s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(3){-webkit-transform:rotate(72deg);-webkit-animation-delay:.375s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(3):after{-webkit-animation-delay:.375s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(4){-webkit-transform:rotate(108deg);-webkit-animation-delay:.5s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(4):after{-webkit-animation-delay:.5s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(5){-webkit-transform:rotate(144deg);-webkit-animation-delay:.625s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(5):after{-webkit-animation-delay:.625s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(6){-webkit-transform:rotate(180deg);-webkit-animation-delay:.75s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(6):after{-webkit-animation-delay:.75s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(7){-webkit-transform:rotate(216deg);-webkit-animation-delay:.875s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(7):after{-webkit-animation-delay:.875s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(8){-webkit-transform:rotate(252deg);-webkit-animation-delay:1s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(8):after{-webkit-animation-delay:1s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(9){-webkit-transform:rotate(288deg);-webkit-animation-delay:1.125s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(9):after{-webkit-animation-delay:1.125s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(10){-webkit-transform:rotate(324deg);-webkit-animation-delay:1.25s}.n-topology.n-topology-dark .n-topology-loading li:nth-child(10):after{-webkit-animation-delay:1.25s}.n-topology.n-topology-dark .n-topology-loading li{-webkit-animation:dotAnimation 2.5s infinite}@-webkit-keyframes dotAnimation{0%,100%,55%{padding:0 0 5.6em}5%,50%{padding:2.8em 0}}.n-topology.n-topology-dark .n-topology-loading li:after{-webkit-animation:dotAnimationTwo 2.5s infinite}@-webkit-keyframes dotAnimationTwo{0%,100%,55%{opacity:1;-webkit-transform:scale(1)}5%,50%{opacity:.5;-webkit-transform:scale(0.5)}}.n-topology.n-topology-green{position:relative;overflow:hidden;background:#fff;-webkit-transition:background .6s;transition:background .6s;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-green:focus{outline:0 none}.n-topology.n-topology-green .n-topology-fit{-webkit-transition:all .6s linear!important;transition:all .6s linear!important}.n-topology.n-topology-green .n-topology-fit .link,.n-topology.n-topology-green .n-topology-fit .linkSet,.n-topology.n-topology-green .n-topology-fit .node,.n-topology.n-topology-green .n-topology-fit .nodeSet{-webkit-transition:all .9s linear!important;transition:all .9s linear!important}.n-topology.n-topology-green.n-topology-loading .n-topology-nav,.n-topology.n-topology-green.n-topology-loading svg{-webkit-filter:blur(5px);-moz-filter:blur(5px)}.n-topology.n-topology-green svg{box-sizing:content-box;position:absolute;top:0;left:0;right:0;bottom:0}.n-topology.n-topology-green text:empty{display:none}.n-topology.n-topology-green g{pointer-events:all}.n-topology.n-topology-green defs .bg{fill:#26999e}.n-topology.n-topology-green defs .stroke{stroke:#26999e}.n-topology.n-topology-green defs [fill*='#FFFFFF']{fill:#fff}.n-topology.n-topology-green .n-svg{border:0;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-green .fontIcon{font-family:next-font;fill:#26999e;alignment-baseline:central;text-anchor:middle;speak:none;font-style:normal;font-weight:400;font-variant:normal;text-transform:none;line-height:1;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.n-topology.n-topology-green text{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.n-topology.n-topology-green .n-topology-icon .fontIcon{cursor:pointer}.n-topology.n-topology-green .iconBG{fill:#fff}.n-topology.n-topology-green .iconBGActive{fill:#26999e}.n-topology.n-topology-green .node:not(.node-selected) .selectedBG{display:none}.n-topology.n-topology-green .node .selectedBG{fill:transparent;opacity:.8;stroke:#f2ad4e;stroke-width:3;pointer-events:none}.n-topology.n-topology-green .node .dot{fill:#26999e}.n-topology.n-topology-green .node text.node-label{font-family:\"Cisco Sans Reg\";fill:#26999e;pointer-events:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;font-size:11px}.n-topology.n-topology-green .node.disable .node-label{fill:#ccc!important}.n-topology.n-topology-green .node.disable .iconBG.iconBGActive,.n-topology.n-topology-green .node.disable .showIcon .iconShape{fill:#ccc}.n-topology.n-topology-green .link line,.n-topology.n-topology-green .link path{stroke:#5edadd;stroke-width:1px;fill:none;cursor:pointer}.n-topology.n-topology-green .link line.link:hover,.n-topology.n-topology-green .link path.link:hover{stroke:#29bfc3}.n-topology.n-topology-green .link line.link_bg:hover~line{stroke:#29bfc3!important}.n-topology.n-topology-green .link .link-label{font-family:\"Cisco Sans Reg\";fill:#26999e;font-size:12px}.n-topology.n-topology-green .link .source-abel,.n-topology.n-topology-green .link .target-label{font-family:\"Cisco Sans Reg\";fill:#26999e;opacity:.8;font-size:12px}.n-topology.n-topology-green .link .disable-label{fill:#fff}.n-topology.n-topology-green .link .disable-bg{fill:#ccc}.n-topology.n-topology-green .link .link_bg{stroke:transparent}.n-topology.n-topology-green .link.disable line,.n-topology.n-topology-green .link.disable path{stroke:#ccc!important;stroke-width:1px}.n-topology.n-topology-green .link.disable .link_bg{stroke:transparent!important}.n-topology.n-topology-green .link.link-selected line,.n-topology.n-topology-green .link.link-selected path{stroke:#ccc;stroke-width:2px}.n-topology.n-topology-green .nodeset .selectedBG{fill:transparent;opacity:.8;stroke:#f2ad4e;stroke-width:3;pointer-events:none}.n-topology.n-topology-green .nodeset .dot{fill:#fff;stroke:#26999e;stroke-width:1}.n-topology.n-topology-green .nodeset .icon{cursor:pointer}.n-topology.n-topology-green .nodeset .bg{fill:#26999e;pointer-events:none}.n-topology.n-topology-green .nodeset text.node-label{font-family:\"Cisco Sans Reg\";fill:#26999e;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;pointer-events:none}.n-topology.n-topology-green .nodeset.disable{opacity:.3;stroke:#ccc}.n-topology.n-topology-green .nodeset .iconBG,.n-topology.n-topology-green .nodeset .iconBGActive{fill:#fff}.n-topology.n-topology-green .nodeset .iconBGActive~.iconShape{display:block!important}.n-topology.n-topology-green .nodeset .indicator .iconBG{fill:#fff}.n-topology.n-topology-green .nodeset .indicator .iconBG:hover{fill:#26999e}.n-topology.n-topology-green .nodeset .indicator .iconShape{fill:#1c7175}.n-topology.n-topology-green .group .bg{opacity:.6;stroke-width:10px;stroke-linejoin:round}.n-topology.n-topology-green .group .groupLabel{cursor:pointer;font-size:18px;font-family:\"Cisco Sans Reg\";text-anchor:middle;alignment-baseline:inherit}.n-topology.n-topology-green .group .fontIcon.iconShape{fill:#9BB150}.n-topology.n-topology-green .group .nodeSetGroupLabel{cursor:pointer;font-size:18px;font-family:\"Cisco Sans Reg\";alignment-baseline:inherit;fill:#9BB150}.n-topology.n-topology-green .group .groupLabel:hover~.bg{opacity:.7}.n-topology.n-topology-green .group.aggregationGroup .bg{stroke-width:10px;stroke-linejoin:round;fill:#9BB150;stroke:#9BB150;pointer-events:none;opacity:0;-webkit-transition:opacity .3s linear;transition:opacity .3s linear}.n-topology.n-topology-green .group.aggregationGroup.fade-active-item{opacity:1}.n-topology.n-topology-green .group.aggregationGroup.fade-active-item .bg{opacity:.5}.n-topology.n-topology-green .link-set-bg{stroke:#5edadd;stroke-width:2px}.n-topology.n-topology-green .link-set-circle{fill:#26999e;stroke:#26999e;stroke-width:16px;stroke-linejoin:round}.n-topology.n-topology-green .link-set-text{font-family:\"Cisco Sans Reg\";fill:#fff;text-anchor:middle;dominant-baseline:central;font-size:12px;pointer-events:none}.n-topology.n-topology-green .link-set.disable .link-set-bg{stroke:#ccc}.n-topology.n-topology-green .link-set.disable .link-set-circle{fill:#ccc;stroke:#ccc}@media screen and (-webkit-min-device-pixel-ratio:0){.n-topology.n-topology-green .link-set-circle,.n-topology.n-topology-green ::i-block-chrome{stroke-width:8px!important}}.n-topology.n-topology-green .mapPath{fill:#cff2f4;stroke:#afe9ec;stroke-width:1;opacity:.5;pointer-events:none}.n-topology.n-topology-green .mapBoundary{fill:none;stroke:#afe9ec;stroke-width:1;pointer-events:none}.n-topology.n-topology-green .selectionRect{stroke:#26999e;fill:#26999e;fill-opacity:.1;pointer-events:none}.n-topology.n-topology-green-setting{max-width:none!important}.n-topology.n-topology-green .aggregationGroup .aggregationText{fill:#26999e;font-size:12px}.n-topology.n-topology-green .aggregationGroup .aggregationRect{fill:#26999e;opacity:.2;stroke:#26999e;stroke-width:3;stroke-linejoin:round;pointer-events:none}.n-topology.n-topology-green .layer>*{transition:opacity .6s}.n-topology.n-topology-green .layer.fade-layer>:not(.fade-highlight-item):not(.fade-active-item),.n-topology.n-topology-green.fade-active-priority.fade-active-occur .layer.fade-layer>.fade-highlight-item:not(.fade-active-item),.n-topology.n-topology-green.fade-active-priority.fade-active-occur.fade-all .layer>.fade-highlight-item:not(.fade-active-item),.n-topology.n-topology-green.fade-all .layer>:not(.fade-highlight-item):not(.fade-active-item){opacity:.2}.n-topology.n-topology-green .n-topology-nav{position:absolute;top:0;left:8px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-green .n-topology-nav li{list-style:none;padding:0}.n-topology.n-topology-green .n-topology-nav ul{padding:0;margin:0}.n-topology.n-topology-green .n-topology-nav span{-webkit-transition:all .6s;transition:all .6s}.n-topology.n-topology-green .n-topology-nav>ul{padding:0;margin-top:30px;width:32px}.n-topology.n-topology-green .n-topology-nav>ul>li{display:inline-block;list-style:none;width:25px;margin-top:5px;-webkit-transition:all .6s;transition:all .6s}.n-topology.n-topology-green .n-topology-nav-mode{padding:0;position:relative;width:25px}.n-topology.n-topology-green .n-topology-nav-mode li{width:25px;height:25px;line-height:30px;display:inline-block;text-align:center;cursor:pointer;-webkit-transition:all .6s;transition:all .6s;background:#eaeaea;margin-top:-2px}.n-topology.n-topology-green .n-topology-nav-mode li:hover span{color:#26999e}.n-topology.n-topology-green .n-topology-nav-mode span{color:#999;display:inline-block;font-size:18px}.n-topology.n-topology-green .n-topology-nav-mode-selected{background:#26999e!important}.n-topology.n-topology-green .n-topology-nav-mode-selected span{color:#fff}.n-topology.n-topology-green .n-topology-nav-mode-selected:hover{background:#26999e!important}.n-topology.n-topology-green .n-topology-nav-mode-selected:hover span{color:#fff!important}.n-topology.n-topology-green .n-topology-nav-zoom{position:relative;height:51px;margin-top:10px!important}.n-topology.n-topology-green .n-topology-nav-zoom>span{display:inline-block;position:absolute;text-align:center;font-size:25px;color:#999;background:#eaeaea}.n-topology.n-topology-green .n-topology-nav-zoom-in{top:0;left:0;cursor:pointer}.n-topology.n-topology-green .n-topology-nav-zoom-in:hover{color:gray;background:#d8d8d8}.n-topology.n-topology-green .n-topology-nav-zoom-out{top:25px;left:0;cursor:pointer}.n-topology.n-topology-green .n-topology-nav-zoom-out:hover{color:gray;background:#d8d8d8}.n-topology.n-topology-green .n-topology-nav-zoom-selection{cursor:pointer;text-align:center;font-size:22px;color:#999}.n-topology.n-topology-green .n-topology-nav-zoom-selection:hover{color:#4d4d4d}.n-topology.n-topology-green .n-topology-nav-zoom-selection-selected{color:#54d0d6}.n-topology.n-topology-green .n-topology-nav-fit{cursor:pointer;text-align:center;font-size:22px;color:#999}.n-topology.n-topology-green .n-topology-nav-fit:hover{color:#4d4d4d}.n-topology.n-topology-green .n-topology-nav-agr{cursor:pointer;line-height:24px;text-align:center;font-size:20px;height:24px;color:#999;display:none}.n-topology.n-topology-green .n-topology-nav-agr:hover{color:#4d4d4d}@-webkit-keyframes agr-icon-ani{0%{-webkit-transform:rotate(0deg)}100%{-webkit-transform:rotate(360deg)}}.n-topology.n-topology-green .n-topology-nav .agr-icon{-webkit-animation-duration:3s;-webkit-animation-name:agr-icon-ani;-webkit-animation-iteration-count:infinite;-webkit-animation-direction:normal;-webkit-animation-timing-function:linear;-webkit-transition:0 none;color:#2badb3}.n-topology.n-topology-green .n-topology-nav .agr-text{font-size:10px;color:#eaeaea;position:absolute;left:10px;margin-top:-1px;height:12px}.n-topology.n-topology-green .n-topology-nav-full{cursor:pointer;text-align:center;font-size:18px;color:#999}.n-topology.n-topology-green .n-topology-nav-full:hover{color:#4d4d4d}.n-topology.n-topology-green .n-topology-nav-setting{cursor:pointer;text-align:center;color:#999;line-height:1;-webkit-transition:none 0!important;transition:none 0!important}.n-topology.n-topology-green .n-topology-nav-setting:hover{opacity:1;color:#2badb3}.n-topology.n-topology-green .n-topology-nav-setting-icon{font-size:20px}.n-topology.n-topology-green .n-topology-nav-setting-icon-selected{color:#2badb3}.n-topology.n-topology-green .n-topology-loading{overflow:hidden;position:absolute;top:0;bottom:0;left:0;right:0;height:100%;width:100%;display:none}.n-topology.n-topology-green .n-topology-loading ul{position:absolute;left:calc(49.3%);top:calc(45.8%);display:inline-block;text-indent:2.8em}.n-topology.n-topology-green .n-topology-loading ul li:after,.n-topology.n-topology-green .n-topology-loading ul:after{width:1.4em;height:1.4em;border-radius:100%;content:\"\";display:block}.n-topology.n-topology-green .n-topology-loading ul:after{position:absolute;top:2.8em}.n-topology.n-topology-green .n-topology-loading li{position:absolute;padding-bottom:5.6em;top:0;left:0;list-style:none}.n-topology.n-topology-green .n-topology-loading li:after{background:#26999e}.n-topology.n-topology-green .n-topology-loading li:nth-child(1){-webkit-transform:rotate(0deg);-webkit-animation-delay:.125s}.n-topology.n-topology-green .n-topology-loading li:nth-child(1):after{-webkit-animation-delay:.125s}.n-topology.n-topology-green .n-topology-loading li:nth-child(2){-webkit-transform:rotate(36deg);-webkit-animation-delay:.25s}.n-topology.n-topology-green .n-topology-loading li:nth-child(2):after{-webkit-animation-delay:.25s}.n-topology.n-topology-green .n-topology-loading li:nth-child(3){-webkit-transform:rotate(72deg);-webkit-animation-delay:.375s}.n-topology.n-topology-green .n-topology-loading li:nth-child(3):after{-webkit-animation-delay:.375s}.n-topology.n-topology-green .n-topology-loading li:nth-child(4){-webkit-transform:rotate(108deg);-webkit-animation-delay:.5s}.n-topology.n-topology-green .n-topology-loading li:nth-child(4):after{-webkit-animation-delay:.5s}.n-topology.n-topology-green .n-topology-loading li:nth-child(5){-webkit-transform:rotate(144deg);-webkit-animation-delay:.625s}.n-topology.n-topology-green .n-topology-loading li:nth-child(5):after{-webkit-animation-delay:.625s}.n-topology.n-topology-green .n-topology-loading li:nth-child(6){-webkit-transform:rotate(180deg);-webkit-animation-delay:.75s}.n-topology.n-topology-green .n-topology-loading li:nth-child(6):after{-webkit-animation-delay:.75s}.n-topology.n-topology-green .n-topology-loading li:nth-child(7){-webkit-transform:rotate(216deg);-webkit-animation-delay:.875s}.n-topology.n-topology-green .n-topology-loading li:nth-child(7):after{-webkit-animation-delay:.875s}.n-topology.n-topology-green .n-topology-loading li:nth-child(8){-webkit-transform:rotate(252deg);-webkit-animation-delay:1s}.n-topology.n-topology-green .n-topology-loading li:nth-child(8):after{-webkit-animation-delay:1s}.n-topology.n-topology-green .n-topology-loading li:nth-child(9){-webkit-transform:rotate(288deg);-webkit-animation-delay:1.125s}.n-topology.n-topology-green .n-topology-loading li:nth-child(9):after{-webkit-animation-delay:1.125s}.n-topology.n-topology-green .n-topology-loading li:nth-child(10){-webkit-transform:rotate(324deg);-webkit-animation-delay:1.25s}.n-topology.n-topology-green .n-topology-loading li:nth-child(10):after{-webkit-animation-delay:1.25s}.n-topology.n-topology-green .n-topology-loading li{-webkit-animation:dotAnimation 2.5s infinite}@-webkit-keyframes dotAnimation{0%,100%,55%{padding:0 0 5.6em}5%,50%{padding:2.8em 0}}.n-topology.n-topology-green .n-topology-loading li:after{-webkit-animation:dotAnimationTwo 2.5s infinite}@-webkit-keyframes dotAnimationTwo{0%,100%,55%{opacity:1;-webkit-transform:scale(1)}5%,50%{opacity:.5;-webkit-transform:scale(0.5)}}.n-topology.n-topology-slate{position:relative;overflow:hidden;background:#223343;-webkit-transition:background .6s;transition:background .6s;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-slate:focus{outline:0 none}.n-topology.n-topology-slate .n-topology-fit{-webkit-transition:all .6s linear!important;transition:all .6s linear!important}.n-topology.n-topology-slate .n-topology-fit .link,.n-topology.n-topology-slate .n-topology-fit .linkSet,.n-topology.n-topology-slate .n-topology-fit .node,.n-topology.n-topology-slate .n-topology-fit .nodeSet{-webkit-transition:all .9s linear!important;transition:all .9s linear!important}.n-topology.n-topology-slate.n-topology-loading .n-topology-nav,.n-topology.n-topology-slate.n-topology-loading svg{-webkit-filter:blur(5px);-moz-filter:blur(5px)}.n-topology.n-topology-slate svg{box-sizing:content-box;position:absolute;top:0;left:0;right:0;bottom:0}.n-topology.n-topology-slate text:empty{display:none}.n-topology.n-topology-slate g{pointer-events:all}.n-topology.n-topology-slate defs .bg{fill:#fff}.n-topology.n-topology-slate defs .stroke{stroke:#fff}.n-topology.n-topology-slate defs [fill*='#FFFFFF']{fill:#223343}.n-topology.n-topology-slate .n-svg{border:0;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-slate .fontIcon{font-family:next-font;fill:#fff;alignment-baseline:central;text-anchor:middle;speak:none;font-style:normal;font-weight:400;font-variant:normal;text-transform:none;line-height:1;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.n-topology.n-topology-slate text{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.n-topology.n-topology-slate .n-topology-icon .fontIcon{cursor:pointer}.n-topology.n-topology-slate .iconBG{fill:#223343}.n-topology.n-topology-slate .iconBGActive{fill:#fff}.n-topology.n-topology-slate .node:not(.node-selected) .selectedBG{display:none}.n-topology.n-topology-slate .node .selectedBG{fill:transparent;opacity:.8;stroke:#f7931e;stroke-width:3;pointer-events:none}.n-topology.n-topology-slate .node .dot{fill:#fff}.n-topology.n-topology-slate .node text.node-label{font-family:\"Cisco Sans Reg\";fill:#fff;pointer-events:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;font-size:11px}.n-topology.n-topology-slate .node.disable .node-label{fill:#ccc!important}.n-topology.n-topology-slate .node.disable .iconBG.iconBGActive,.n-topology.n-topology-slate .node.disable .showIcon .iconShape{fill:#ccc}.n-topology.n-topology-slate .link line,.n-topology.n-topology-slate .link path{stroke:#49a9bf;stroke-width:1px;fill:none;cursor:pointer}.n-topology.n-topology-slate .link line.link:hover,.n-topology.n-topology-slate .link path.link:hover{stroke:#307889}.n-topology.n-topology-slate .link line.link_bg:hover~line{stroke:#307889!important}.n-topology.n-topology-slate .link .link-label{font-family:\"Cisco Sans Reg\";fill:#fff;font-size:12px}.n-topology.n-topology-slate .link .source-abel,.n-topology.n-topology-slate .link .target-label{font-family:\"Cisco Sans Reg\";fill:#fff;opacity:.8;font-size:12px}.n-topology.n-topology-slate .link .disable-label{fill:#fff}.n-topology.n-topology-slate .link .disable-bg{fill:#ccc}.n-topology.n-topology-slate .link .link_bg{stroke:transparent}.n-topology.n-topology-slate .link.disable line,.n-topology.n-topology-slate .link.disable path{stroke:#ccc!important;stroke-width:1px}.n-topology.n-topology-slate .link.disable .link_bg{stroke:transparent!important}.n-topology.n-topology-slate .link.link-selected line,.n-topology.n-topology-slate .link.link-selected path{stroke:#ccc;stroke-width:2px}.n-topology.n-topology-slate .nodeset .selectedBG{fill:transparent;opacity:.8;stroke:#f7931e;stroke-width:3;pointer-events:none}.n-topology.n-topology-slate .nodeset .dot{fill:#223343;stroke:#fff;stroke-width:1}.n-topology.n-topology-slate .nodeset .icon{cursor:pointer}.n-topology.n-topology-slate .nodeset .bg{fill:#fff;pointer-events:none}.n-topology.n-topology-slate .nodeset text.node-label{font-family:\"Cisco Sans Reg\";fill:#fff;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;pointer-events:none}.n-topology.n-topology-slate .nodeset.disable{opacity:.3;stroke:#ccc}.n-topology.n-topology-slate .nodeset .iconBG,.n-topology.n-topology-slate .nodeset .iconBGActive{fill:#223343}.n-topology.n-topology-slate .nodeset .iconBGActive~.iconShape{display:block!important}.n-topology.n-topology-slate .nodeset .indicator .iconBG{fill:#223343}.n-topology.n-topology-slate .nodeset .indicator .iconBG:hover{fill:#fff}.n-topology.n-topology-slate .nodeset .indicator .iconShape{fill:#e6e6e6}.n-topology.n-topology-slate .group .bg{opacity:.6;stroke-width:10px;stroke-linejoin:round}.n-topology.n-topology-slate .group .groupLabel{cursor:pointer;font-size:18px;font-family:\"Cisco Sans Reg\";text-anchor:middle;alignment-baseline:inherit}.n-topology.n-topology-slate .group .fontIcon.iconShape{fill:#9BB150}.n-topology.n-topology-slate .group .nodeSetGroupLabel{cursor:pointer;font-size:18px;font-family:\"Cisco Sans Reg\";alignment-baseline:inherit;fill:#9BB150}.n-topology.n-topology-slate .group .groupLabel:hover~.bg{opacity:.7}.n-topology.n-topology-slate .group.aggregationGroup .bg{stroke-width:10px;stroke-linejoin:round;fill:#9BB150;stroke:#9BB150;pointer-events:none;opacity:0;-webkit-transition:opacity .3s linear;transition:opacity .3s linear}.n-topology.n-topology-slate .group.aggregationGroup.fade-active-item{opacity:1}.n-topology.n-topology-slate .group.aggregationGroup.fade-active-item .bg{opacity:.5}.n-topology.n-topology-slate .link-set-bg{stroke:#49a9bf;stroke-width:2px}.n-topology.n-topology-slate .link-set-circle{fill:#fff;stroke:#fff;stroke-width:16px;stroke-linejoin:round}.n-topology.n-topology-slate .link-set-text{font-family:\"Cisco Sans Reg\";fill:#223343;text-anchor:middle;dominant-baseline:central;font-size:12px;pointer-events:none}.n-topology.n-topology-slate .link-set.disable .link-set-bg{stroke:#ccc}.n-topology.n-topology-slate .link-set.disable .link-set-circle{fill:#ccc;stroke:#ccc}@media screen and (-webkit-min-device-pixel-ratio:0){.n-topology.n-topology-slate .link-set-circle,.n-topology.n-topology-slate ::i-block-chrome{stroke-width:8px!important}}.n-topology.n-topology-slate .mapPath{fill:#fff;stroke:#eee;stroke-width:1;opacity:.5;pointer-events:none}.n-topology.n-topology-slate .mapBoundary{fill:none;stroke:#eee;stroke-width:1;pointer-events:none}.n-topology.n-topology-slate .selectionRect{stroke:#fff;fill:#fff;fill-opacity:.1;pointer-events:none}.n-topology.n-topology-slate-setting{max-width:none!important}.n-topology.n-topology-slate .aggregationGroup .aggregationText{fill:#fff;font-size:12px}.n-topology.n-topology-slate .aggregationGroup .aggregationRect{fill:#fff;opacity:.2;stroke:#fff;stroke-width:3;stroke-linejoin:round;pointer-events:none}.n-topology.n-topology-slate .layer>*{transition:opacity .6s}.n-topology.n-topology-slate .layer.fade-layer>:not(.fade-highlight-item):not(.fade-active-item),.n-topology.n-topology-slate.fade-active-priority.fade-active-occur .layer.fade-layer>.fade-highlight-item:not(.fade-active-item),.n-topology.n-topology-slate.fade-active-priority.fade-active-occur.fade-all .layer>.fade-highlight-item:not(.fade-active-item),.n-topology.n-topology-slate.fade-all .layer>:not(.fade-highlight-item):not(.fade-active-item){opacity:.2}.n-topology.n-topology-slate .n-topology-nav{position:absolute;top:0;left:8px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-slate .n-topology-nav li{list-style:none;padding:0}.n-topology.n-topology-slate .n-topology-nav ul{padding:0;margin:0}.n-topology.n-topology-slate .n-topology-nav span{-webkit-transition:all .6s;transition:all .6s}.n-topology.n-topology-slate .n-topology-nav>ul{padding:0;margin-top:30px;width:32px}.n-topology.n-topology-slate .n-topology-nav>ul>li{display:inline-block;list-style:none;width:25px;margin-top:5px;-webkit-transition:all .6s;transition:all .6s}.n-topology.n-topology-slate .n-topology-nav-mode{padding:0;position:relative;width:25px}.n-topology.n-topology-slate .n-topology-nav-mode li{width:25px;height:25px;line-height:30px;display:inline-block;text-align:center;cursor:pointer;-webkit-transition:all .6s;transition:all .6s;background:#446787;margin-top:-2px}.n-topology.n-topology-slate .n-topology-nav-mode li:hover span{color:#fff}.n-topology.n-topology-slate .n-topology-nav-mode span{color:#888;display:inline-block;font-size:18px}.n-topology.n-topology-slate .n-topology-nav-mode-selected{background:#fff!important}.n-topology.n-topology-slate .n-topology-nav-mode-selected span{color:#223343}.n-topology.n-topology-slate .n-topology-nav-mode-selected:hover{background:#fff!important}.n-topology.n-topology-slate .n-topology-nav-mode-selected:hover span{color:#223343!important}.n-topology.n-topology-slate .n-topology-nav-zoom{position:relative;height:51px;margin-top:10px!important}.n-topology.n-topology-slate .n-topology-nav-zoom>span{display:inline-block;position:absolute;text-align:center;font-size:25px;color:#888;background:#446787}.n-topology.n-topology-slate .n-topology-nav-zoom-in{top:0;left:0;cursor:pointer}.n-topology.n-topology-slate .n-topology-nav-zoom-in:hover{color:#d5d5d5;background:#5680a8}.n-topology.n-topology-slate .n-topology-nav-zoom-out{top:25px;left:0;cursor:pointer}.n-topology.n-topology-slate .n-topology-nav-zoom-out:hover{color:#d5d5d5;background:#5680a8}.n-topology.n-topology-slate .n-topology-nav-zoom-selection{cursor:pointer;text-align:center;font-size:22px;color:#888}.n-topology.n-topology-slate .n-topology-nav-zoom-selection:hover{color:#d5d5d5}.n-topology.n-topology-slate .n-topology-nav-zoom-selection-selected{color:#fff}.n-topology.n-topology-slate .n-topology-nav-fit{cursor:pointer;text-align:center;font-size:22px;color:#888}.n-topology.n-topology-slate .n-topology-nav-fit:hover{color:#d5d5d5}.n-topology.n-topology-slate .n-topology-nav-agr{cursor:pointer;line-height:24px;text-align:center;font-size:20px;height:24px;color:#888;display:none}.n-topology.n-topology-slate .n-topology-nav-agr:hover{color:#d5d5d5}@-webkit-keyframes agr-icon-ani{0%{-webkit-transform:rotate(0deg)}100%{-webkit-transform:rotate(360deg)}}.n-topology.n-topology-slate .n-topology-nav .agr-icon{-webkit-animation-duration:3s;-webkit-animation-name:agr-icon-ani;-webkit-animation-iteration-count:infinite;-webkit-animation-direction:normal;-webkit-animation-timing-function:linear;-webkit-transition:0 none;color:#fff}.n-topology.n-topology-slate .n-topology-nav .agr-text{font-size:10px;color:#446787;position:absolute;left:10px;margin-top:-1px;height:12px}.n-topology.n-topology-slate .n-topology-nav-full{cursor:pointer;text-align:center;font-size:18px;color:#888}.n-topology.n-topology-slate .n-topology-nav-full:hover{color:#d5d5d5}.n-topology.n-topology-slate .n-topology-nav-setting{cursor:pointer;text-align:center;color:#888;line-height:1;-webkit-transition:none 0!important;transition:none 0!important}.n-topology.n-topology-slate .n-topology-nav-setting:hover{opacity:1;color:#fff}.n-topology.n-topology-slate .n-topology-nav-setting-icon{font-size:20px}.n-topology.n-topology-slate .n-topology-nav-setting-icon-selected{color:#fff}.n-topology.n-topology-slate .n-topology-loading{overflow:hidden;position:absolute;top:0;bottom:0;left:0;right:0;height:100%;width:100%;display:none}.n-topology.n-topology-slate .n-topology-loading ul{position:absolute;left:calc(49.3%);top:calc(45.8%);display:inline-block;text-indent:2.8em}.n-topology.n-topology-slate .n-topology-loading ul li:after,.n-topology.n-topology-slate .n-topology-loading ul:after{width:1.4em;height:1.4em;border-radius:100%;content:\"\";display:block}.n-topology.n-topology-slate .n-topology-loading ul:after{position:absolute;top:2.8em}.n-topology.n-topology-slate .n-topology-loading li{position:absolute;padding-bottom:5.6em;top:0;left:0;list-style:none}.n-topology.n-topology-slate .n-topology-loading li:after{background:#fff}.n-topology.n-topology-slate .n-topology-loading li:nth-child(1){-webkit-transform:rotate(0deg);-webkit-animation-delay:.125s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(1):after{-webkit-animation-delay:.125s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(2){-webkit-transform:rotate(36deg);-webkit-animation-delay:.25s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(2):after{-webkit-animation-delay:.25s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(3){-webkit-transform:rotate(72deg);-webkit-animation-delay:.375s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(3):after{-webkit-animation-delay:.375s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(4){-webkit-transform:rotate(108deg);-webkit-animation-delay:.5s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(4):after{-webkit-animation-delay:.5s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(5){-webkit-transform:rotate(144deg);-webkit-animation-delay:.625s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(5):after{-webkit-animation-delay:.625s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(6){-webkit-transform:rotate(180deg);-webkit-animation-delay:.75s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(6):after{-webkit-animation-delay:.75s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(7){-webkit-transform:rotate(216deg);-webkit-animation-delay:.875s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(7):after{-webkit-animation-delay:.875s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(8){-webkit-transform:rotate(252deg);-webkit-animation-delay:1s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(8):after{-webkit-animation-delay:1s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(9){-webkit-transform:rotate(288deg);-webkit-animation-delay:1.125s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(9):after{-webkit-animation-delay:1.125s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(10){-webkit-transform:rotate(324deg);-webkit-animation-delay:1.25s}.n-topology.n-topology-slate .n-topology-loading li:nth-child(10):after{-webkit-animation-delay:1.25s}.n-topology.n-topology-slate .n-topology-loading li{-webkit-animation:dotAnimation 2.5s infinite}@-webkit-keyframes dotAnimation{0%,100%,55%{padding:0 0 5.6em}5%,50%{padding:2.8em 0}}.n-topology.n-topology-slate .n-topology-loading li:after{-webkit-animation:dotAnimationTwo 2.5s infinite}@-webkit-keyframes dotAnimationTwo{0%,100%,55%{opacity:1;-webkit-transform:scale(1)}5%,50%{opacity:.5;-webkit-transform:scale(0.5)}}.n-topology.n-topology-yellow{position:relative;overflow:hidden;background:#000;-webkit-transition:background .6s;transition:background .6s;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-yellow:focus{outline:0 none}.n-topology.n-topology-yellow .n-topology-fit{-webkit-transition:all .6s linear!important;transition:all .6s linear!important}.n-topology.n-topology-yellow .n-topology-fit .link,.n-topology.n-topology-yellow .n-topology-fit .linkSet,.n-topology.n-topology-yellow .n-topology-fit .node,.n-topology.n-topology-yellow .n-topology-fit .nodeSet{-webkit-transition:all .9s linear!important;transition:all .9s linear!important}.n-topology.n-topology-yellow.n-topology-loading .n-topology-nav,.n-topology.n-topology-yellow.n-topology-loading svg{-webkit-filter:blur(5px);-moz-filter:blur(5px)}.n-topology.n-topology-yellow svg{box-sizing:content-box;position:absolute;top:0;left:0;right:0;bottom:0}.n-topology.n-topology-yellow text:empty{display:none}.n-topology.n-topology-yellow g{pointer-events:all}.n-topology.n-topology-yellow defs .bg{fill:#ffc200}.n-topology.n-topology-yellow defs .stroke{stroke:#ffc200}.n-topology.n-topology-yellow defs [fill*='#FFFFFF']{fill:#000}.n-topology.n-topology-yellow .n-svg{border:0;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-yellow .fontIcon{font-family:next-font;fill:#ffc200;alignment-baseline:central;text-anchor:middle;speak:none;font-style:normal;font-weight:400;font-variant:normal;text-transform:none;line-height:1;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.n-topology.n-topology-yellow text{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.n-topology.n-topology-yellow .n-topology-icon .fontIcon{cursor:pointer}.n-topology.n-topology-yellow .iconBG{fill:#000}.n-topology.n-topology-yellow .iconBGActive{fill:#ffc200}.n-topology.n-topology-yellow .node:not(.node-selected) .selectedBG{display:none}.n-topology.n-topology-yellow .node .selectedBG{fill:transparent;opacity:.8;stroke:#ff7900;stroke-width:3;pointer-events:none}.n-topology.n-topology-yellow .node .dot{fill:#ffc200}.n-topology.n-topology-yellow .node text.node-label{font-family:\"Cisco Sans Reg\";fill:#ffc200;pointer-events:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;font-size:11px}.n-topology.n-topology-yellow .node.disable .node-label{fill:#ccc!important}.n-topology.n-topology-yellow .node.disable .iconBG.iconBGActive,.n-topology.n-topology-yellow .node.disable .showIcon .iconShape{fill:#ccc}.n-topology.n-topology-yellow .link line,.n-topology.n-topology-yellow .link path{stroke:#997b19;stroke-width:1px;fill:none;cursor:pointer}.n-topology.n-topology-yellow .link line.link:hover,.n-topology.n-topology-yellow .link path.link:hover{stroke:#55440e}.n-topology.n-topology-yellow .link line.link_bg:hover~line{stroke:#55440e!important}.n-topology.n-topology-yellow .link .link-label{font-family:\"Cisco Sans Reg\";fill:#ffc200;font-size:12px}.n-topology.n-topology-yellow .link .source-abel,.n-topology.n-topology-yellow .link .target-label{font-family:\"Cisco Sans Reg\";fill:#ffc200;opacity:.8;font-size:12px}.n-topology.n-topology-yellow .link .disable-label{fill:#fff}.n-topology.n-topology-yellow .link .disable-bg{fill:#ccc}.n-topology.n-topology-yellow .link .link_bg{stroke:transparent}.n-topology.n-topology-yellow .link.disable line,.n-topology.n-topology-yellow .link.disable path{stroke:#ccc!important;stroke-width:1px}.n-topology.n-topology-yellow .link.disable .link_bg{stroke:transparent!important}.n-topology.n-topology-yellow .link.link-selected line,.n-topology.n-topology-yellow .link.link-selected path{stroke:#ccc;stroke-width:2px}.n-topology.n-topology-yellow .nodeset .selectedBG{fill:transparent;opacity:.8;stroke:#ff7900;stroke-width:3;pointer-events:none}.n-topology.n-topology-yellow .nodeset .dot{fill:#000;stroke:#ffc200;stroke-width:1}.n-topology.n-topology-yellow .nodeset .icon{cursor:pointer}.n-topology.n-topology-yellow .nodeset .bg{fill:#ffc200;pointer-events:none}.n-topology.n-topology-yellow .nodeset text.node-label{font-family:\"Cisco Sans Reg\";fill:#ffc200;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;pointer-events:none}.n-topology.n-topology-yellow .nodeset.disable{opacity:.3;stroke:#ccc}.n-topology.n-topology-yellow .nodeset .iconBG,.n-topology.n-topology-yellow .nodeset .iconBGActive{fill:#000}.n-topology.n-topology-yellow .nodeset .iconBGActive~.iconShape{display:block!important}.n-topology.n-topology-yellow .nodeset .indicator .iconBG{fill:#000}.n-topology.n-topology-yellow .nodeset .indicator .iconBG:hover{fill:#ffc200}.n-topology.n-topology-yellow .nodeset .indicator .iconShape{fill:#cc9b00}.n-topology.n-topology-yellow .group .bg{opacity:.6;stroke-width:10px;stroke-linejoin:round}.n-topology.n-topology-yellow .group .groupLabel{cursor:pointer;font-size:18px;font-family:\"Cisco Sans Reg\";text-anchor:middle;alignment-baseline:inherit}.n-topology.n-topology-yellow .group .fontIcon.iconShape{fill:#9BB150}.n-topology.n-topology-yellow .group .nodeSetGroupLabel{cursor:pointer;font-size:18px;font-family:\"Cisco Sans Reg\";alignment-baseline:inherit;fill:#9BB150}.n-topology.n-topology-yellow .group .groupLabel:hover~.bg{opacity:.7}.n-topology.n-topology-yellow .group.aggregationGroup .bg{stroke-width:10px;stroke-linejoin:round;fill:#9BB150;stroke:#9BB150;pointer-events:none;opacity:0;-webkit-transition:opacity .3s linear;transition:opacity .3s linear}.n-topology.n-topology-yellow .group.aggregationGroup.fade-active-item{opacity:1}.n-topology.n-topology-yellow .group.aggregationGroup.fade-active-item .bg{opacity:.5}.n-topology.n-topology-yellow .link-set-bg{stroke:#997b19;stroke-width:2px}.n-topology.n-topology-yellow .link-set-circle{fill:#ffc200;stroke:#ffc200;stroke-width:16px;stroke-linejoin:round}.n-topology.n-topology-yellow .link-set-text{font-family:\"Cisco Sans Reg\";fill:#000;text-anchor:middle;dominant-baseline:central;font-size:12px;pointer-events:none}.n-topology.n-topology-yellow .link-set.disable .link-set-bg{stroke:#ccc}.n-topology.n-topology-yellow .link-set.disable .link-set-circle{fill:#ccc;stroke:#ccc}@media screen and (-webkit-min-device-pixel-ratio:0){.n-topology.n-topology-yellow .link-set-circle,.n-topology.n-topology-yellow ::i-block-chrome{stroke-width:8px!important}}.n-topology.n-topology-yellow .mapPath{fill:#333;stroke:#555;stroke-width:1;opacity:.5;pointer-events:none}.n-topology.n-topology-yellow .mapBoundary{fill:none;stroke:#555;stroke-width:1;pointer-events:none}.n-topology.n-topology-yellow .selectionRect{stroke:#ffc200;fill:#ffc200;fill-opacity:.1;pointer-events:none}.n-topology.n-topology-yellow-setting{max-width:none!important}.n-topology.n-topology-yellow .aggregationGroup .aggregationText{fill:#ffc200;font-size:12px}.n-topology.n-topology-yellow .aggregationGroup .aggregationRect{fill:#ffc200;opacity:.2;stroke:#ffc200;stroke-width:3;stroke-linejoin:round;pointer-events:none}.n-topology.n-topology-yellow .layer>*{transition:opacity .6s}.n-topology.n-topology-yellow .layer.fade-layer>:not(.fade-highlight-item):not(.fade-active-item),.n-topology.n-topology-yellow.fade-active-priority.fade-active-occur .layer.fade-layer>.fade-highlight-item:not(.fade-active-item),.n-topology.n-topology-yellow.fade-active-priority.fade-active-occur.fade-all .layer>.fade-highlight-item:not(.fade-active-item),.n-topology.n-topology-yellow.fade-all .layer>:not(.fade-highlight-item):not(.fade-active-item){opacity:.2}.n-topology.n-topology-yellow .n-topology-nav{position:absolute;top:0;left:8px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-topology.n-topology-yellow .n-topology-nav li{list-style:none;padding:0}.n-topology.n-topology-yellow .n-topology-nav ul{padding:0;margin:0}.n-topology.n-topology-yellow .n-topology-nav span{-webkit-transition:all .6s;transition:all .6s}.n-topology.n-topology-yellow .n-topology-nav>ul{padding:0;margin-top:30px;width:32px}.n-topology.n-topology-yellow .n-topology-nav>ul>li{display:inline-block;list-style:none;width:25px;margin-top:5px;-webkit-transition:all .6s;transition:all .6s}.n-topology.n-topology-yellow .n-topology-nav-mode{padding:0;position:relative;width:25px}.n-topology.n-topology-yellow .n-topology-nav-mode li{width:25px;height:25px;line-height:30px;display:inline-block;text-align:center;cursor:pointer;-webkit-transition:all .6s;transition:all .6s;background:#333;margin-top:-2px}.n-topology.n-topology-yellow .n-topology-nav-mode li:hover span{color:#ffc200}.n-topology.n-topology-yellow .n-topology-nav-mode span{color:#666;display:inline-block;font-size:18px}.n-topology.n-topology-yellow .n-topology-nav-mode-selected{background:#ffc200!important}.n-topology.n-topology-yellow .n-topology-nav-mode-selected span{color:#000}.n-topology.n-topology-yellow .n-topology-nav-mode-selected:hover{background:#ffc200!important}.n-topology.n-topology-yellow .n-topology-nav-mode-selected:hover span{color:#000!important}.n-topology.n-topology-yellow .n-topology-nav-zoom{position:relative;height:51px;margin-top:10px!important}.n-topology.n-topology-yellow .n-topology-nav-zoom>span{display:inline-block;position:absolute;text-align:center;font-size:25px;color:#666;background:#333}.n-topology.n-topology-yellow .n-topology-nav-zoom-in{top:0;left:0;cursor:pointer}.n-topology.n-topology-yellow .n-topology-nav-zoom-in:hover{color:#b3b3b3;background:#4d4d4d}.n-topology.n-topology-yellow .n-topology-nav-zoom-out{top:25px;left:0;cursor:pointer}.n-topology.n-topology-yellow .n-topology-nav-zoom-out:hover{color:#b3b3b3;background:#4d4d4d}.n-topology.n-topology-yellow .n-topology-nav-zoom-selection{cursor:pointer;text-align:center;font-size:22px;color:#666}.n-topology.n-topology-yellow .n-topology-nav-zoom-selection:hover{color:#b3b3b3}.n-topology.n-topology-yellow .n-topology-nav-zoom-selection-selected{color:#ffda66}.n-topology.n-topology-yellow .n-topology-nav-fit{cursor:pointer;text-align:center;font-size:22px;color:#666}.n-topology.n-topology-yellow .n-topology-nav-fit:hover{color:#b3b3b3}.n-topology.n-topology-yellow .n-topology-nav-agr{cursor:pointer;line-height:24px;text-align:center;font-size:20px;height:24px;color:#666;display:none}.n-topology.n-topology-yellow .n-topology-nav-agr:hover{color:#b3b3b3}@-webkit-keyframes agr-icon-ani{0%{-webkit-transform:rotate(0deg)}100%{-webkit-transform:rotate(360deg)}}.n-topology.n-topology-yellow .n-topology-nav .agr-icon{-webkit-animation-duration:3s;-webkit-animation-name:agr-icon-ani;-webkit-animation-iteration-count:infinite;-webkit-animation-direction:normal;-webkit-animation-timing-function:linear;-webkit-transition:0 none;color:#ffc81a}.n-topology.n-topology-yellow .n-topology-nav .agr-text{font-size:10px;color:#333;position:absolute;left:10px;margin-top:-1px;height:12px}.n-topology.n-topology-yellow .n-topology-nav-full{cursor:pointer;text-align:center;font-size:18px;color:#666}.n-topology.n-topology-yellow .n-topology-nav-full:hover{color:#b3b3b3}.n-topology.n-topology-yellow .n-topology-nav-setting{cursor:pointer;text-align:center;color:#666;line-height:1;-webkit-transition:none 0!important;transition:none 0!important}.n-topology.n-topology-yellow .n-topology-nav-setting:hover{opacity:1;color:#ffc81a}.n-topology.n-topology-yellow .n-topology-nav-setting-icon{font-size:20px}.n-topology.n-topology-yellow .n-topology-nav-setting-icon-selected{color:#ffc81a}.n-topology.n-topology-yellow .n-topology-loading{overflow:hidden;position:absolute;top:0;bottom:0;left:0;right:0;height:100%;width:100%;display:none}.n-topology.n-topology-yellow .n-topology-loading ul{position:absolute;left:calc(49.3%);top:calc(45.8%);display:inline-block;text-indent:2.8em}.n-topology.n-topology-yellow .n-topology-loading ul li:after,.n-topology.n-topology-yellow .n-topology-loading ul:after{width:1.4em;height:1.4em;border-radius:100%;content:\"\";display:block}.n-topology.n-topology-yellow .n-topology-loading ul:after{position:absolute;top:2.8em}.n-topology.n-topology-yellow .n-topology-loading li{position:absolute;padding-bottom:5.6em;top:0;left:0;list-style:none}.n-topology.n-topology-yellow .n-topology-loading li:after{background:#ffc200}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(1){-webkit-transform:rotate(0deg);-webkit-animation-delay:.125s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(1):after{-webkit-animation-delay:.125s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(2){-webkit-transform:rotate(36deg);-webkit-animation-delay:.25s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(2):after{-webkit-animation-delay:.25s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(3){-webkit-transform:rotate(72deg);-webkit-animation-delay:.375s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(3):after{-webkit-animation-delay:.375s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(4){-webkit-transform:rotate(108deg);-webkit-animation-delay:.5s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(4):after{-webkit-animation-delay:.5s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(5){-webkit-transform:rotate(144deg);-webkit-animation-delay:.625s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(5):after{-webkit-animation-delay:.625s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(6){-webkit-transform:rotate(180deg);-webkit-animation-delay:.75s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(6):after{-webkit-animation-delay:.75s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(7){-webkit-transform:rotate(216deg);-webkit-animation-delay:.875s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(7):after{-webkit-animation-delay:.875s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(8){-webkit-transform:rotate(252deg);-webkit-animation-delay:1s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(8):after{-webkit-animation-delay:1s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(9){-webkit-transform:rotate(288deg);-webkit-animation-delay:1.125s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(9):after{-webkit-animation-delay:1.125s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(10){-webkit-transform:rotate(324deg);-webkit-animation-delay:1.25s}.n-topology.n-topology-yellow .n-topology-loading li:nth-child(10):after{-webkit-animation-delay:1.25s}.n-topology.n-topology-yellow .n-topology-loading li{-webkit-animation:dotAnimation 2.5s infinite}@-webkit-keyframes dotAnimation{0%,100%,55%{padding:0 0 5.6em}5%,50%{padding:2.8em 0}}.n-topology.n-topology-yellow .n-topology-loading li:after{-webkit-animation:dotAnimationTwo 2.5s infinite}@-webkit-keyframes dotAnimationTwo{0%,100%,55%{opacity:1;-webkit-transform:scale(1)}5%,50%{opacity:.5;-webkit-transform:scale(0.5)}}.n-topology-tooltip{padding:0;opacity:.8!important;max-height:450px}.n-topology-tooltip-header{min-width:160px;line-height:24px;position:relative;border-bottom:dotted 1px #ccc}.n-topology-tooltip-header-actions{float:right}.n-topology-tooltip-header-actions i{cursor:pointer}.n-topology-tooltip-header-text{line-height:24px;color:#333;font-size:14px;font-weight:700}.n-topology-tooltip-content{margin-bottom:6px;padding:3px;min-height:30px}.n-topology-tooltip-content label{display:inline-block;margin-right:8px;font-weight:700}.n-topology-tooltip-content ul{margin:0;padding:0}.n-topology-tooltip-content li{list-style:none}.n-topology-tooltip:after{display:none}.n-topology-tooltip .popover-content{padding:5px 10px}.n-topology-setting-panel{max-width:342px!important;font-family:Arial}.n-topology-setting-panel .popover-content{width:330px;line-height:24px;height:auto}.n-topology-setting-panel .popover-content h3{margin:4px 0 6px}.n-topology-setting-panel .popover-content h5{margin:5px 0}.n-topology-setting-panel .popover-content label{font-size:12px;margin-right:12px}.n-topology-setting-panel .popover-content .btn-group button{margin:0;margin-right:-1px}.n-topology-setting-panel .popover-content .n-radio{margin-right:12px;font-weight:400}.n-topology-setting-panel .popover-content .n-radio span{margin-left:3px}.n-topology-setting-panel .popover-content-label{display:inline-block;margin-right:20px}.n-topology-setting-panel .popover-content .toggleLabelCheckBox{float:right;margin-right:12px}.n-topology-thumbnail{position:absolute;border:solid 1px #ccc;box-shadow:0 0 10px #ccc;margin-top:-10px;margin-left:-10px;z-index:100;background:#fff}.n-topology-thumbnail-container{position:relative}.n-topology-thumbnail-win{position:absolute;border:solid 1px red}.n-topology-thumbnail-svg{border:solid 1px #c4c4c4;background:#fff}.n-topology-thumbnail .handler{position:absolute;bottom:0;right:0;cursor:pointer}.n-userselect,.n-userselect *{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.n-transition{-webkit-transition:all .4!important;transition:all .4s!important}.n-moveCursor{cursor:move!important}.n-dragCursor{cursor:pointer}.n-crosshairCursor,.n-crosshairCursor *{cursor:crosshair!important}.n-zoomInCursor{cursor:-webkit-zoom-in;cursor:zoom-in}.n-waitCursor{cursor:wait}.n-blockEvent,.n-blockEvent *{pointer-events:none}.n-hidden{display:none!important}.clearfix:after,.clearfix:before{content:\" \";display:table}.clearfix:after{clear:both}.center-block{display:block;margin-left:auto;margin-right:auto}.pull-right{float:right!important}.pull-left{float:left!important}.hide{display:none!important}.show{display:block!important}.invisible{visibility:hidden}.text-hide{font:0/0 a;color:transparent;text-shadow:none;background-color:transparent;border:0}.hidden{display:none!important;visibility:hidden!important}.affix{position:fixed}.btn{display:inline-block;margin-bottom:0;font-weight:400;text-align:center;vertical-align:middle;cursor:pointer;background-image:none;border:1px solid transparent;white-space:nowrap;padding:6px 12px;font-size:14px;line-height:1.42857143;border-radius:4px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}.btn:focus{outline:thin dotted #333;outline:5px auto -webkit-focus-ring-color;outline-offset:-2px}.btn:focus,.btn:hover{color:#333;text-decoration:none}.btn.active,.btn:active{outline:0;background-image:none;-webkit-box-shadow:inset 0 3px 5px rgba(0,0,0,.125);box-shadow:inset 0 3px 5px rgba(0,0,0,.125)}.btn.disabled,.btn[disabled],fieldset[disabled] .btn{cursor:not-allowed;pointer-events:none;opacity:.65;filter:alpha(opacity=65);-webkit-box-shadow:none;box-shadow:none}.btn-default{color:#333;background-color:#fff;border-color:#ccc}.btn-default.active,.btn-default:active,.btn-default:focus,.btn-default:hover,.open .dropdown-toggle.btn-default{color:#333;background-color:#ebebeb;border-color:#adadad}.btn-default.active,.btn-default:active,.open .dropdown-toggle.btn-default{background-image:none}.btn-default.disabled,.btn-default.disabled.active,.btn-default.disabled:active,.btn-default.disabled:focus,.btn-default.disabled:hover,.btn-default[disabled],.btn-default[disabled].active,.btn-default[disabled]:active,.btn-default[disabled]:focus,.btn-default[disabled]:hover,fieldset[disabled] .btn-default,fieldset[disabled] .btn-default.active,fieldset[disabled] .btn-default:active,fieldset[disabled] .btn-default:focus,fieldset[disabled] .btn-default:hover{background-color:#fff;border-color:#ccc}.btn-primary{color:#fff;background-color:#0386d2;border-color:#0376b9}.btn-primary.active,.btn-primary:active,.btn-primary:focus,.btn-primary:hover,.open .dropdown-toggle.btn-primary{color:#fff;background-color:#026caa;border-color:#024f7d}.btn-primary.active,.btn-primary:active,.open .dropdown-toggle.btn-primary{background-image:none}.btn-primary.disabled,.btn-primary.disabled.active,.btn-primary.disabled:active,.btn-primary.disabled:focus,.btn-primary.disabled:hover,.btn-primary[disabled],.btn-primary[disabled].active,.btn-primary[disabled]:active,.btn-primary[disabled]:focus,.btn-primary[disabled]:hover,fieldset[disabled] .btn-primary,fieldset[disabled] .btn-primary.active,fieldset[disabled] .btn-primary:active,fieldset[disabled] .btn-primary:focus,fieldset[disabled] .btn-primary:hover{background-color:#0386d2;border-color:#0376b9}.btn-warning{color:#fff;background-color:#f2ad4e;border-color:#f0a236}.btn-warning.active,.btn-warning:active,.btn-warning:focus,.btn-warning:hover,.open .dropdown-toggle.btn-warning{color:#fff;background-color:#ef9b28;border-color:#d98510}.btn-warning.active,.btn-warning:active,.open .dropdown-toggle.btn-warning{background-image:none}.btn-warning.disabled,.btn-warning.disabled.active,.btn-warning.disabled:active,.btn-warning.disabled:focus,.btn-warning.disabled:hover,.btn-warning[disabled],.btn-warning[disabled].active,.btn-warning[disabled]:active,.btn-warning[disabled]:focus,.btn-warning[disabled]:hover,fieldset[disabled] .btn-warning,fieldset[disabled] .btn-warning.active,fieldset[disabled] .btn-warning:active,fieldset[disabled] .btn-warning:focus,fieldset[disabled] .btn-warning:hover{background-color:#f2ad4e;border-color:#f0a236}.btn-danger{color:#fff;background-color:#da534f;border-color:#d63e3a}.btn-danger.active,.btn-danger:active,.btn-danger:focus,.btn-danger:hover,.open .dropdown-toggle.btn-danger{color:#fff;background-color:#d3322d;border-color:#ae2825}.btn-danger.active,.btn-danger:active,.open .dropdown-toggle.btn-danger{background-image:none}.btn-danger.disabled,.btn-danger.disabled.active,.btn-danger.disabled:active,.btn-danger.disabled:focus,.btn-danger.disabled:hover,.btn-danger[disabled],.btn-danger[disabled].active,.btn-danger[disabled]:active,.btn-danger[disabled]:focus,.btn-danger[disabled]:hover,fieldset[disabled] .btn-danger,fieldset[disabled] .btn-danger.active,fieldset[disabled] .btn-danger:active,fieldset[disabled] .btn-danger:focus,fieldset[disabled] .btn-danger:hover{background-color:#da534f;border-color:#d63e3a}.btn-success{color:#fff;background-color:#5cb85c;border-color:#4cae4c}.btn-success.active,.btn-success:active,.btn-success:focus,.btn-success:hover,.open .dropdown-toggle.btn-success{color:#fff;background-color:#47a447;border-color:#398439}.btn-success.active,.btn-success:active,.open .dropdown-toggle.btn-success{background-image:none}.btn-success.disabled,.btn-success.disabled.active,.btn-success.disabled:active,.btn-success.disabled:focus,.btn-success.disabled:hover,.btn-success[disabled],.btn-success[disabled].active,.btn-success[disabled]:active,.btn-success[disabled]:focus,.btn-success[disabled]:hover,fieldset[disabled] .btn-success,fieldset[disabled] .btn-success.active,fieldset[disabled] .btn-success:active,fieldset[disabled] .btn-success:focus,fieldset[disabled] .btn-success:hover{background-color:#5cb85c;border-color:#4cae4c}.btn-info{color:#fff;background-color:#5bc1df;border-color:#46b9db}.btn-info.active,.btn-info:active,.btn-info:focus,.btn-info:hover,.open .dropdown-toggle.btn-info{color:#fff;background-color:#39b4d8;border-color:#259bbe}.btn-info.active,.btn-info:active,.open .dropdown-toggle.btn-info{background-image:none}.btn-info.disabled,.btn-info.disabled.active,.btn-info.disabled:active,.btn-info.disabled:focus,.btn-info.disabled:hover,.btn-info[disabled],.btn-info[disabled].active,.btn-info[disabled]:active,.btn-info[disabled]:focus,.btn-info[disabled]:hover,fieldset[disabled] .btn-info,fieldset[disabled] .btn-info.active,fieldset[disabled] .btn-info:active,fieldset[disabled] .btn-info:focus,fieldset[disabled] .btn-info:hover{background-color:#5bc1df;border-color:#46b9db}.btn-link{color:#0386d2;font-weight:400;cursor:pointer;border-radius:0}.btn-link,.btn-link:active,.btn-link[disabled],fieldset[disabled] .btn-link{background-color:transparent;-webkit-box-shadow:none;box-shadow:none}.btn-link,.btn-link:active,.btn-link:focus,.btn-link:hover{border-color:transparent}.btn-link:focus,.btn-link:hover{color:#025687;text-decoration:underline;background-color:transparent}.btn-link[disabled]:focus,.btn-link[disabled]:hover,fieldset[disabled] .btn-link:focus,fieldset[disabled] .btn-link:hover{color:#999;text-decoration:none}.btn-lg{padding:10px 16px;font-size:18px;line-height:1.33;border-radius:6px}.btn-sm,.btn-xs{padding:5px 10px;font-size:12px;line-height:1.5;border-radius:3px}.btn-xs{padding:1px 5px}.btn-block{display:block;width:100%;padding-left:0;padding-right:0}.btn-block+.btn-block{margin-top:5px}input[type=button].btn-block,input[type=reset].btn-block,input[type=submit].btn-block{width:100%}.btn-default .caret{border-top-color:#333}.btn-danger .caret,.btn-info .caret,.btn-primary .caret,.btn-success .caret,.btn-warning .caret{border-top-color:#fff}.dropup .btn-default .caret{border-bottom-color:#333}.dropup .btn-danger .caret,.dropup .btn-info .caret,.dropup .btn-primary .caret,.dropup .btn-success .caret,.dropup .btn-warning .caret{border-bottom-color:#fff}.btn-group,.btn-group-vertical{position:relative;display:inline-block;vertical-align:middle}.btn-group-vertical>.btn,.btn-group>.btn{position:relative;float:left}.btn-group-vertical>.btn.active,.btn-group-vertical>.btn:active,.btn-group-vertical>.btn:focus,.btn-group-vertical>.btn:hover,.btn-group>.btn.active,.btn-group>.btn:active,.btn-group>.btn:focus,.btn-group>.btn:hover{z-index:2}.btn-group-vertical>.btn:focus,.btn-group>.btn:focus{outline:0}.btn-group .btn+.btn,.btn-group .btn+.btn-group,.btn-group .btn-group+.btn,.btn-group .btn-group+.btn-group{margin-left:-1px}.btn-toolbar:after,.btn-toolbar:before{content:\" \";display:table}.btn-toolbar:after{clear:both}.btn-toolbar .btn-group{float:left}.btn-toolbar>.btn+.btn,.btn-toolbar>.btn+.btn-group,.btn-toolbar>.btn-group+.btn,.btn-toolbar>.btn-group+.btn-group{margin-left:5px}.btn-group>.btn:not(:first-child):not(:last-child):not(.dropdown-toggle){border-radius:0}.btn-group>.btn:first-child{margin-left:0}.btn-group>.btn:first-child:not(:last-child):not(.dropdown-toggle){border-bottom-right-radius:0;border-top-right-radius:0}.btn-group>.btn:last-child:not(:first-child),.btn-group>.dropdown-toggle:not(:first-child){border-bottom-left-radius:0;border-top-left-radius:0}.btn-group>.btn-group{float:left}.btn-group>.btn-group:not(:first-child):not(:last-child)>.btn{border-radius:0}.btn-group>.btn-group:first-child>.btn:last-child,.btn-group>.btn-group:first-child>.dropdown-toggle{border-bottom-right-radius:0;border-top-right-radius:0}.btn-group>.btn-group:last-child>.btn:first-child{border-bottom-left-radius:0;border-top-left-radius:0}.btn-group .dropdown-toggle:active,.btn-group.open .dropdown-toggle{outline:0}.btn-group-xs>.btn{font-size:12px;line-height:1.5;border-radius:3px;padding:1px 5px}.btn-group-sm>.btn{padding:5px 10px;font-size:12px;line-height:1.5;border-radius:3px}.btn-group-lg>.btn{padding:10px 16px;font-size:18px;line-height:1.33;border-radius:6px}.btn-group>.btn+.dropdown-toggle{padding-left:8px;padding-right:8px}.btn-group>.btn-lg+.dropdown-toggle{padding-left:12px;padding-right:12px}.btn-group.open .dropdown-toggle{-webkit-box-shadow:inset 0 3px 5px rgba(0,0,0,.125);box-shadow:inset 0 3px 5px rgba(0,0,0,.125)}.btn-group.open .dropdown-toggle.btn-link{-webkit-box-shadow:none;box-shadow:none}.btn .caret{margin-left:0}.btn-lg .caret{border-width:5px 5px 0;border-bottom-width:0}.dropup .btn-lg .caret{border-width:0 5px 5px}.btn-group-vertical>.btn,.btn-group-vertical>.btn-group{display:block;float:none;width:100%;max-width:100%}.btn-group-vertical>.btn-group:after,.btn-group-vertical>.btn-group:before{content:\" \";display:table}.btn-group-vertical>.btn-group:after{clear:both}.btn-group-vertical>.btn-group>.btn{float:none}.btn-group-vertical>.btn+.btn,.btn-group-vertical>.btn+.btn-group,.btn-group-vertical>.btn-group+.btn,.btn-group-vertical>.btn-group+.btn-group{margin-top:-1px;margin-left:0}.btn-group-vertical>.btn:not(:first-child):not(:last-child){border-radius:0}.btn-group-vertical>.btn:first-child:not(:last-child){border-top-right-radius:4px;border-bottom-right-radius:0;border-bottom-left-radius:0}.btn-group-vertical>.btn:last-child:not(:first-child){border-bottom-left-radius:4px;border-top-right-radius:0;border-top-left-radius:0}.btn-group-vertical>.btn-group:not(:first-child):not(:last-child)>.btn{border-radius:0}.btn-group-vertical>.btn-group:first-child>.btn:last-child,.btn-group-vertical>.btn-group:first-child>.dropdown-toggle{border-bottom-right-radius:0;border-bottom-left-radius:0}.btn-group-vertical>.btn-group:last-child>.btn:first-child{border-top-right-radius:0;border-top-left-radius:0}.btn-group-justified{display:table;width:100%;table-layout:fixed;border-collapse:separate}.btn-group-justified .btn{float:none;display:table-cell;width:1%}[data-toggle=buttons]>.btn>input[type=checkbox],[data-toggle=buttons]>.btn>input[type=radio]{display:none}.popover{position:absolute;top:0;left:0;z-index:1010;display:none;max-width:276px;padding:1px;text-align:left;background-color:#fff;background-clip:padding-box;border:1px solid #ccc;border:1px solid rgba(0,0,0,.2);border-radius:6px;-webkit-box-shadow:0 5px 10px rgba(0,0,0,.2);box-shadow:0 5px 10px rgba(0,0,0,.2);white-space:normal}.popover.top{margin-top:-10px}.popover.right{margin-left:10px}.popover.bottom{margin-top:10px}.popover.left{margin-left:-10px}.popover-title{margin:0;padding:8px 14px;font-size:14px;font-weight:400;line-height:18px;background-color:#f7f7f7;border-bottom:1px solid #ebebeb;border-radius:5px 5px 0 0}.popover-content{padding:9px 14px}.popover .arrow,.popover .arrow:after{position:absolute;display:block;width:0;height:0;border-color:transparent;border-style:solid}.popover .arrow{border-width:11px}.popover .arrow:after{border-width:10px;content:\"\"}.popover.top .arrow{left:50%;margin-left:-11px;border-bottom-width:0;border-top-color:#999;border-top-color:rgba(0,0,0,.25);bottom:-11px}.popover.top .arrow:after{content:\" \";bottom:1px;margin-left:-10px;border-bottom-width:0;border-top-color:#fff}.popover.right .arrow{top:50%;left:-11px;margin-top:-11px;border-left-width:0;border-right-color:#999;border-right-color:rgba(0,0,0,.25)}.popover.right .arrow:after{content:\" \";left:1px;bottom:-10px;border-left-width:0;border-right-color:#fff}.popover.bottom .arrow{left:50%;margin-left:-11px;border-top-width:0;border-bottom-color:#999;border-bottom-color:rgba(0,0,0,.25);top:-11px}.popover.bottom .arrow:after{content:\" \";top:1px;margin-left:-10px;border-top-width:0;border-bottom-color:#fff}.popover.left .arrow{top:50%;right:-11px;margin-top:-11px;border-right-width:0;border-left-color:#999;border-left-color:rgba(0,0,0,.25)}.popover.left .arrow:after{content:\" \";right:1px;border-right-width:0;border-left-color:#fff;bottom:-10px}";
styleInject(css_248z);

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

function unwrapExports (x) {
	return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;
}

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

/** @license React v16.13.1
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var b="function"===typeof Symbol&&Symbol.for,c=b?Symbol.for("react.element"):60103,d=b?Symbol.for("react.portal"):60106,e=b?Symbol.for("react.fragment"):60107,f=b?Symbol.for("react.strict_mode"):60108,g=b?Symbol.for("react.profiler"):60114,h=b?Symbol.for("react.provider"):60109,k=b?Symbol.for("react.context"):60110,l=b?Symbol.for("react.async_mode"):60111,m=b?Symbol.for("react.concurrent_mode"):60111,n=b?Symbol.for("react.forward_ref"):60112,p=b?Symbol.for("react.suspense"):60113,q=b?
Symbol.for("react.suspense_list"):60120,r=b?Symbol.for("react.memo"):60115,t=b?Symbol.for("react.lazy"):60116,v=b?Symbol.for("react.block"):60121,w=b?Symbol.for("react.fundamental"):60117,x=b?Symbol.for("react.responder"):60118,y=b?Symbol.for("react.scope"):60119;
function z(a){if("object"===typeof a&&null!==a){var u=a.$$typeof;switch(u){case c:switch(a=a.type,a){case l:case m:case e:case g:case f:case p:return a;default:switch(a=a&&a.$$typeof,a){case k:case n:case t:case r:case h:return a;default:return u}}case d:return u}}}function A(a){return z(a)===m}var AsyncMode=l;var ConcurrentMode=m;var ContextConsumer=k;var ContextProvider=h;var Element=c;var ForwardRef=n;var Fragment=e;var Lazy=t;var Memo=r;var Portal=d;
var Profiler=g;var StrictMode=f;var Suspense=p;var isAsyncMode=function(a){return A(a)||z(a)===l};var isConcurrentMode=A;var isContextConsumer=function(a){return z(a)===k};var isContextProvider=function(a){return z(a)===h};var isElement=function(a){return "object"===typeof a&&null!==a&&a.$$typeof===c};var isForwardRef=function(a){return z(a)===n};var isFragment=function(a){return z(a)===e};var isLazy=function(a){return z(a)===t};
var isMemo=function(a){return z(a)===r};var isPortal=function(a){return z(a)===d};var isProfiler=function(a){return z(a)===g};var isStrictMode=function(a){return z(a)===f};var isSuspense=function(a){return z(a)===p};
var isValidElementType=function(a){return "string"===typeof a||"function"===typeof a||a===e||a===m||a===g||a===f||a===p||a===q||"object"===typeof a&&null!==a&&(a.$$typeof===t||a.$$typeof===r||a.$$typeof===h||a.$$typeof===k||a.$$typeof===n||a.$$typeof===w||a.$$typeof===x||a.$$typeof===y||a.$$typeof===v)};var typeOf=z;

var reactIs_production_min = {
	AsyncMode: AsyncMode,
	ConcurrentMode: ConcurrentMode,
	ContextConsumer: ContextConsumer,
	ContextProvider: ContextProvider,
	Element: Element,
	ForwardRef: ForwardRef,
	Fragment: Fragment,
	Lazy: Lazy,
	Memo: Memo,
	Portal: Portal,
	Profiler: Profiler,
	StrictMode: StrictMode,
	Suspense: Suspense,
	isAsyncMode: isAsyncMode,
	isConcurrentMode: isConcurrentMode,
	isContextConsumer: isContextConsumer,
	isContextProvider: isContextProvider,
	isElement: isElement,
	isForwardRef: isForwardRef,
	isFragment: isFragment,
	isLazy: isLazy,
	isMemo: isMemo,
	isPortal: isPortal,
	isProfiler: isProfiler,
	isStrictMode: isStrictMode,
	isSuspense: isSuspense,
	isValidElementType: isValidElementType,
	typeOf: typeOf
};

var reactIs_development = createCommonjsModule(function (module, exports) {



if (process.env.NODE_ENV !== "production") {
  (function() {

// The Symbol used to tag the ReactElement-like types. If there is no native Symbol
// nor polyfill, then a plain number is used for performance.
var hasSymbol = typeof Symbol === 'function' && Symbol.for;
var REACT_ELEMENT_TYPE = hasSymbol ? Symbol.for('react.element') : 0xeac7;
var REACT_PORTAL_TYPE = hasSymbol ? Symbol.for('react.portal') : 0xeaca;
var REACT_FRAGMENT_TYPE = hasSymbol ? Symbol.for('react.fragment') : 0xeacb;
var REACT_STRICT_MODE_TYPE = hasSymbol ? Symbol.for('react.strict_mode') : 0xeacc;
var REACT_PROFILER_TYPE = hasSymbol ? Symbol.for('react.profiler') : 0xead2;
var REACT_PROVIDER_TYPE = hasSymbol ? Symbol.for('react.provider') : 0xeacd;
var REACT_CONTEXT_TYPE = hasSymbol ? Symbol.for('react.context') : 0xeace; // TODO: We don't use AsyncMode or ConcurrentMode anymore. They were temporary
// (unstable) APIs that have been removed. Can we remove the symbols?

var REACT_ASYNC_MODE_TYPE = hasSymbol ? Symbol.for('react.async_mode') : 0xeacf;
var REACT_CONCURRENT_MODE_TYPE = hasSymbol ? Symbol.for('react.concurrent_mode') : 0xeacf;
var REACT_FORWARD_REF_TYPE = hasSymbol ? Symbol.for('react.forward_ref') : 0xead0;
var REACT_SUSPENSE_TYPE = hasSymbol ? Symbol.for('react.suspense') : 0xead1;
var REACT_SUSPENSE_LIST_TYPE = hasSymbol ? Symbol.for('react.suspense_list') : 0xead8;
var REACT_MEMO_TYPE = hasSymbol ? Symbol.for('react.memo') : 0xead3;
var REACT_LAZY_TYPE = hasSymbol ? Symbol.for('react.lazy') : 0xead4;
var REACT_BLOCK_TYPE = hasSymbol ? Symbol.for('react.block') : 0xead9;
var REACT_FUNDAMENTAL_TYPE = hasSymbol ? Symbol.for('react.fundamental') : 0xead5;
var REACT_RESPONDER_TYPE = hasSymbol ? Symbol.for('react.responder') : 0xead6;
var REACT_SCOPE_TYPE = hasSymbol ? Symbol.for('react.scope') : 0xead7;

function isValidElementType(type) {
  return typeof type === 'string' || typeof type === 'function' || // Note: its typeof might be other than 'symbol' or 'number' if it's a polyfill.
  type === REACT_FRAGMENT_TYPE || type === REACT_CONCURRENT_MODE_TYPE || type === REACT_PROFILER_TYPE || type === REACT_STRICT_MODE_TYPE || type === REACT_SUSPENSE_TYPE || type === REACT_SUSPENSE_LIST_TYPE || typeof type === 'object' && type !== null && (type.$$typeof === REACT_LAZY_TYPE || type.$$typeof === REACT_MEMO_TYPE || type.$$typeof === REACT_PROVIDER_TYPE || type.$$typeof === REACT_CONTEXT_TYPE || type.$$typeof === REACT_FORWARD_REF_TYPE || type.$$typeof === REACT_FUNDAMENTAL_TYPE || type.$$typeof === REACT_RESPONDER_TYPE || type.$$typeof === REACT_SCOPE_TYPE || type.$$typeof === REACT_BLOCK_TYPE);
}

function typeOf(object) {
  if (typeof object === 'object' && object !== null) {
    var $$typeof = object.$$typeof;

    switch ($$typeof) {
      case REACT_ELEMENT_TYPE:
        var type = object.type;

        switch (type) {
          case REACT_ASYNC_MODE_TYPE:
          case REACT_CONCURRENT_MODE_TYPE:
          case REACT_FRAGMENT_TYPE:
          case REACT_PROFILER_TYPE:
          case REACT_STRICT_MODE_TYPE:
          case REACT_SUSPENSE_TYPE:
            return type;

          default:
            var $$typeofType = type && type.$$typeof;

            switch ($$typeofType) {
              case REACT_CONTEXT_TYPE:
              case REACT_FORWARD_REF_TYPE:
              case REACT_LAZY_TYPE:
              case REACT_MEMO_TYPE:
              case REACT_PROVIDER_TYPE:
                return $$typeofType;

              default:
                return $$typeof;
            }

        }

      case REACT_PORTAL_TYPE:
        return $$typeof;
    }
  }

  return undefined;
} // AsyncMode is deprecated along with isAsyncMode

var AsyncMode = REACT_ASYNC_MODE_TYPE;
var ConcurrentMode = REACT_CONCURRENT_MODE_TYPE;
var ContextConsumer = REACT_CONTEXT_TYPE;
var ContextProvider = REACT_PROVIDER_TYPE;
var Element = REACT_ELEMENT_TYPE;
var ForwardRef = REACT_FORWARD_REF_TYPE;
var Fragment = REACT_FRAGMENT_TYPE;
var Lazy = REACT_LAZY_TYPE;
var Memo = REACT_MEMO_TYPE;
var Portal = REACT_PORTAL_TYPE;
var Profiler = REACT_PROFILER_TYPE;
var StrictMode = REACT_STRICT_MODE_TYPE;
var Suspense = REACT_SUSPENSE_TYPE;
var hasWarnedAboutDeprecatedIsAsyncMode = false; // AsyncMode should be deprecated

function isAsyncMode(object) {
  {
    if (!hasWarnedAboutDeprecatedIsAsyncMode) {
      hasWarnedAboutDeprecatedIsAsyncMode = true; // Using console['warn'] to evade Babel and ESLint

      console['warn']('The ReactIs.isAsyncMode() alias has been deprecated, ' + 'and will be removed in React 17+. Update your code to use ' + 'ReactIs.isConcurrentMode() instead. It has the exact same API.');
    }
  }

  return isConcurrentMode(object) || typeOf(object) === REACT_ASYNC_MODE_TYPE;
}
function isConcurrentMode(object) {
  return typeOf(object) === REACT_CONCURRENT_MODE_TYPE;
}
function isContextConsumer(object) {
  return typeOf(object) === REACT_CONTEXT_TYPE;
}
function isContextProvider(object) {
  return typeOf(object) === REACT_PROVIDER_TYPE;
}
function isElement(object) {
  return typeof object === 'object' && object !== null && object.$$typeof === REACT_ELEMENT_TYPE;
}
function isForwardRef(object) {
  return typeOf(object) === REACT_FORWARD_REF_TYPE;
}
function isFragment(object) {
  return typeOf(object) === REACT_FRAGMENT_TYPE;
}
function isLazy(object) {
  return typeOf(object) === REACT_LAZY_TYPE;
}
function isMemo(object) {
  return typeOf(object) === REACT_MEMO_TYPE;
}
function isPortal(object) {
  return typeOf(object) === REACT_PORTAL_TYPE;
}
function isProfiler(object) {
  return typeOf(object) === REACT_PROFILER_TYPE;
}
function isStrictMode(object) {
  return typeOf(object) === REACT_STRICT_MODE_TYPE;
}
function isSuspense(object) {
  return typeOf(object) === REACT_SUSPENSE_TYPE;
}

exports.AsyncMode = AsyncMode;
exports.ConcurrentMode = ConcurrentMode;
exports.ContextConsumer = ContextConsumer;
exports.ContextProvider = ContextProvider;
exports.Element = Element;
exports.ForwardRef = ForwardRef;
exports.Fragment = Fragment;
exports.Lazy = Lazy;
exports.Memo = Memo;
exports.Portal = Portal;
exports.Profiler = Profiler;
exports.StrictMode = StrictMode;
exports.Suspense = Suspense;
exports.isAsyncMode = isAsyncMode;
exports.isConcurrentMode = isConcurrentMode;
exports.isContextConsumer = isContextConsumer;
exports.isContextProvider = isContextProvider;
exports.isElement = isElement;
exports.isForwardRef = isForwardRef;
exports.isFragment = isFragment;
exports.isLazy = isLazy;
exports.isMemo = isMemo;
exports.isPortal = isPortal;
exports.isProfiler = isProfiler;
exports.isStrictMode = isStrictMode;
exports.isSuspense = isSuspense;
exports.isValidElementType = isValidElementType;
exports.typeOf = typeOf;
  })();
}
});
var reactIs_development_1 = reactIs_development.AsyncMode;
var reactIs_development_2 = reactIs_development.ConcurrentMode;
var reactIs_development_3 = reactIs_development.ContextConsumer;
var reactIs_development_4 = reactIs_development.ContextProvider;
var reactIs_development_5 = reactIs_development.Element;
var reactIs_development_6 = reactIs_development.ForwardRef;
var reactIs_development_7 = reactIs_development.Fragment;
var reactIs_development_8 = reactIs_development.Lazy;
var reactIs_development_9 = reactIs_development.Memo;
var reactIs_development_10 = reactIs_development.Portal;
var reactIs_development_11 = reactIs_development.Profiler;
var reactIs_development_12 = reactIs_development.StrictMode;
var reactIs_development_13 = reactIs_development.Suspense;
var reactIs_development_14 = reactIs_development.isAsyncMode;
var reactIs_development_15 = reactIs_development.isConcurrentMode;
var reactIs_development_16 = reactIs_development.isContextConsumer;
var reactIs_development_17 = reactIs_development.isContextProvider;
var reactIs_development_18 = reactIs_development.isElement;
var reactIs_development_19 = reactIs_development.isForwardRef;
var reactIs_development_20 = reactIs_development.isFragment;
var reactIs_development_21 = reactIs_development.isLazy;
var reactIs_development_22 = reactIs_development.isMemo;
var reactIs_development_23 = reactIs_development.isPortal;
var reactIs_development_24 = reactIs_development.isProfiler;
var reactIs_development_25 = reactIs_development.isStrictMode;
var reactIs_development_26 = reactIs_development.isSuspense;
var reactIs_development_27 = reactIs_development.isValidElementType;
var reactIs_development_28 = reactIs_development.typeOf;

var reactIs = createCommonjsModule(function (module) {

if (process.env.NODE_ENV === 'production') {
  module.exports = reactIs_production_min;
} else {
  module.exports = reactIs_development;
}
});

/*
object-assign
(c) Sindre Sorhus
@license MIT
*/
/* eslint-disable no-unused-vars */
var getOwnPropertySymbols = Object.getOwnPropertySymbols;
var hasOwnProperty = Object.prototype.hasOwnProperty;
var propIsEnumerable = Object.prototype.propertyIsEnumerable;

function toObject(val) {
	if (val === null || val === undefined) {
		throw new TypeError('Object.assign cannot be called with null or undefined');
	}

	return Object(val);
}

function shouldUseNative() {
	try {
		if (!Object.assign) {
			return false;
		}

		// Detect buggy property enumeration order in older V8 versions.

		// https://bugs.chromium.org/p/v8/issues/detail?id=4118
		var test1 = new String('abc');  // eslint-disable-line no-new-wrappers
		test1[5] = 'de';
		if (Object.getOwnPropertyNames(test1)[0] === '5') {
			return false;
		}

		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
		var test2 = {};
		for (var i = 0; i < 10; i++) {
			test2['_' + String.fromCharCode(i)] = i;
		}
		var order2 = Object.getOwnPropertyNames(test2).map(function (n) {
			return test2[n];
		});
		if (order2.join('') !== '0123456789') {
			return false;
		}

		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
		var test3 = {};
		'abcdefghijklmnopqrst'.split('').forEach(function (letter) {
			test3[letter] = letter;
		});
		if (Object.keys(Object.assign({}, test3)).join('') !==
				'abcdefghijklmnopqrst') {
			return false;
		}

		return true;
	} catch (err) {
		// We don't expect any of the above to throw, but better to be safe.
		return false;
	}
}

var objectAssign = shouldUseNative() ? Object.assign : function (target, source) {
	var from;
	var to = toObject(target);
	var symbols;

	for (var s = 1; s < arguments.length; s++) {
		from = Object(arguments[s]);

		for (var key in from) {
			if (hasOwnProperty.call(from, key)) {
				to[key] = from[key];
			}
		}

		if (getOwnPropertySymbols) {
			symbols = getOwnPropertySymbols(from);
			for (var i = 0; i < symbols.length; i++) {
				if (propIsEnumerable.call(from, symbols[i])) {
					to[symbols[i]] = from[symbols[i]];
				}
			}
		}
	}

	return to;
};

/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var ReactPropTypesSecret = 'SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED';

var ReactPropTypesSecret_1 = ReactPropTypesSecret;

var printWarning = function() {};

if (process.env.NODE_ENV !== 'production') {
  var ReactPropTypesSecret$1 = ReactPropTypesSecret_1;
  var loggedTypeFailures = {};
  var has = Function.call.bind(Object.prototype.hasOwnProperty);

  printWarning = function(text) {
    var message = 'Warning: ' + text;
    if (typeof console !== 'undefined') {
      console.error(message);
    }
    try {
      // --- Welcome to debugging React ---
      // This error was thrown as a convenience so that you can use this stack
      // to find the callsite that caused this warning to fire.
      throw new Error(message);
    } catch (x) {}
  };
}

/**
 * Assert that the values match with the type specs.
 * Error messages are memorized and will only be shown once.
 *
 * @param {object} typeSpecs Map of name to a ReactPropType
 * @param {object} values Runtime values that need to be type-checked
 * @param {string} location e.g. "prop", "context", "child context"
 * @param {string} componentName Name of the component for error messages.
 * @param {?Function} getStack Returns the component stack.
 * @private
 */
function checkPropTypes(typeSpecs, values, location, componentName, getStack) {
  if (process.env.NODE_ENV !== 'production') {
    for (var typeSpecName in typeSpecs) {
      if (has(typeSpecs, typeSpecName)) {
        var error;
        // Prop type validation may throw. In case they do, we don't want to
        // fail the render phase where it didn't fail before. So we log it.
        // After these have been cleaned up, we'll let them throw.
        try {
          // This is intentionally an invariant that gets caught. It's the same
          // behavior as without this statement except with a better message.
          if (typeof typeSpecs[typeSpecName] !== 'function') {
            var err = Error(
              (componentName || 'React class') + ': ' + location + ' type `' + typeSpecName + '` is invalid; ' +
              'it must be a function, usually from the `prop-types` package, but received `' + typeof typeSpecs[typeSpecName] + '`.'
            );
            err.name = 'Invariant Violation';
            throw err;
          }
          error = typeSpecs[typeSpecName](values, typeSpecName, componentName, location, null, ReactPropTypesSecret$1);
        } catch (ex) {
          error = ex;
        }
        if (error && !(error instanceof Error)) {
          printWarning(
            (componentName || 'React class') + ': type specification of ' +
            location + ' `' + typeSpecName + '` is invalid; the type checker ' +
            'function must return `null` or an `Error` but returned a ' + typeof error + '. ' +
            'You may have forgotten to pass an argument to the type checker ' +
            'creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and ' +
            'shape all require an argument).'
          );
        }
        if (error instanceof Error && !(error.message in loggedTypeFailures)) {
          // Only monitor this failure once because there tends to be a lot of the
          // same error.
          loggedTypeFailures[error.message] = true;

          var stack = getStack ? getStack() : '';

          printWarning(
            'Failed ' + location + ' type: ' + error.message + (stack != null ? stack : '')
          );
        }
      }
    }
  }
}

/**
 * Resets warning cache when testing.
 *
 * @private
 */
checkPropTypes.resetWarningCache = function() {
  if (process.env.NODE_ENV !== 'production') {
    loggedTypeFailures = {};
  }
};

var checkPropTypes_1 = checkPropTypes;

var has$1 = Function.call.bind(Object.prototype.hasOwnProperty);
var printWarning$1 = function() {};

if (process.env.NODE_ENV !== 'production') {
  printWarning$1 = function(text) {
    var message = 'Warning: ' + text;
    if (typeof console !== 'undefined') {
      console.error(message);
    }
    try {
      // --- Welcome to debugging React ---
      // This error was thrown as a convenience so that you can use this stack
      // to find the callsite that caused this warning to fire.
      throw new Error(message);
    } catch (x) {}
  };
}

function emptyFunctionThatReturnsNull() {
  return null;
}

var factoryWithTypeCheckers = function(isValidElement, throwOnDirectAccess) {
  /* global Symbol */
  var ITERATOR_SYMBOL = typeof Symbol === 'function' && Symbol.iterator;
  var FAUX_ITERATOR_SYMBOL = '@@iterator'; // Before Symbol spec.

  /**
   * Returns the iterator method function contained on the iterable object.
   *
   * Be sure to invoke the function with the iterable as context:
   *
   *     var iteratorFn = getIteratorFn(myIterable);
   *     if (iteratorFn) {
   *       var iterator = iteratorFn.call(myIterable);
   *       ...
   *     }
   *
   * @param {?object} maybeIterable
   * @return {?function}
   */
  function getIteratorFn(maybeIterable) {
    var iteratorFn = maybeIterable && (ITERATOR_SYMBOL && maybeIterable[ITERATOR_SYMBOL] || maybeIterable[FAUX_ITERATOR_SYMBOL]);
    if (typeof iteratorFn === 'function') {
      return iteratorFn;
    }
  }

  /**
   * Collection of methods that allow declaration and validation of props that are
   * supplied to React components. Example usage:
   *
   *   var Props = require('ReactPropTypes');
   *   var MyArticle = React.createClass({
   *     propTypes: {
   *       // An optional string prop named "description".
   *       description: Props.string,
   *
   *       // A required enum prop named "category".
   *       category: Props.oneOf(['News','Photos']).isRequired,
   *
   *       // A prop named "dialog" that requires an instance of Dialog.
   *       dialog: Props.instanceOf(Dialog).isRequired
   *     },
   *     render: function() { ... }
   *   });
   *
   * A more formal specification of how these methods are used:
   *
   *   type := array|bool|func|object|number|string|oneOf([...])|instanceOf(...)
   *   decl := ReactPropTypes.{type}(.isRequired)?
   *
   * Each and every declaration produces a function with the same signature. This
   * allows the creation of custom validation functions. For example:
   *
   *  var MyLink = React.createClass({
   *    propTypes: {
   *      // An optional string or URI prop named "href".
   *      href: function(props, propName, componentName) {
   *        var propValue = props[propName];
   *        if (propValue != null && typeof propValue !== 'string' &&
   *            !(propValue instanceof URI)) {
   *          return new Error(
   *            'Expected a string or an URI for ' + propName + ' in ' +
   *            componentName
   *          );
   *        }
   *      }
   *    },
   *    render: function() {...}
   *  });
   *
   * @internal
   */

  var ANONYMOUS = '<<anonymous>>';

  // Important!
  // Keep this list in sync with production version in `./factoryWithThrowingShims.js`.
  var ReactPropTypes = {
    array: createPrimitiveTypeChecker('array'),
    bool: createPrimitiveTypeChecker('boolean'),
    func: createPrimitiveTypeChecker('function'),
    number: createPrimitiveTypeChecker('number'),
    object: createPrimitiveTypeChecker('object'),
    string: createPrimitiveTypeChecker('string'),
    symbol: createPrimitiveTypeChecker('symbol'),

    any: createAnyTypeChecker(),
    arrayOf: createArrayOfTypeChecker,
    element: createElementTypeChecker(),
    elementType: createElementTypeTypeChecker(),
    instanceOf: createInstanceTypeChecker,
    node: createNodeChecker(),
    objectOf: createObjectOfTypeChecker,
    oneOf: createEnumTypeChecker,
    oneOfType: createUnionTypeChecker,
    shape: createShapeTypeChecker,
    exact: createStrictShapeTypeChecker,
  };

  /**
   * inlined Object.is polyfill to avoid requiring consumers ship their own
   * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/is
   */
  /*eslint-disable no-self-compare*/
  function is(x, y) {
    // SameValue algorithm
    if (x === y) {
      // Steps 1-5, 7-10
      // Steps 6.b-6.e: +0 != -0
      return x !== 0 || 1 / x === 1 / y;
    } else {
      // Step 6.a: NaN == NaN
      return x !== x && y !== y;
    }
  }
  /*eslint-enable no-self-compare*/

  /**
   * We use an Error-like object for backward compatibility as people may call
   * PropTypes directly and inspect their output. However, we don't use real
   * Errors anymore. We don't inspect their stack anyway, and creating them
   * is prohibitively expensive if they are created too often, such as what
   * happens in oneOfType() for any type before the one that matched.
   */
  function PropTypeError(message) {
    this.message = message;
    this.stack = '';
  }
  // Make `instanceof Error` still work for returned errors.
  PropTypeError.prototype = Error.prototype;

  function createChainableTypeChecker(validate) {
    if (process.env.NODE_ENV !== 'production') {
      var manualPropTypeCallCache = {};
      var manualPropTypeWarningCount = 0;
    }
    function checkType(isRequired, props, propName, componentName, location, propFullName, secret) {
      componentName = componentName || ANONYMOUS;
      propFullName = propFullName || propName;

      if (secret !== ReactPropTypesSecret_1) {
        if (throwOnDirectAccess) {
          // New behavior only for users of `prop-types` package
          var err = new Error(
            'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
            'Use `PropTypes.checkPropTypes()` to call them. ' +
            'Read more at http://fb.me/use-check-prop-types'
          );
          err.name = 'Invariant Violation';
          throw err;
        } else if (process.env.NODE_ENV !== 'production' && typeof console !== 'undefined') {
          // Old behavior for people using React.PropTypes
          var cacheKey = componentName + ':' + propName;
          if (
            !manualPropTypeCallCache[cacheKey] &&
            // Avoid spamming the console because they are often not actionable except for lib authors
            manualPropTypeWarningCount < 3
          ) {
            printWarning$1(
              'You are manually calling a React.PropTypes validation ' +
              'function for the `' + propFullName + '` prop on `' + componentName  + '`. This is deprecated ' +
              'and will throw in the standalone `prop-types` package. ' +
              'You may be seeing this warning due to a third-party PropTypes ' +
              'library. See https://fb.me/react-warning-dont-call-proptypes ' + 'for details.'
            );
            manualPropTypeCallCache[cacheKey] = true;
            manualPropTypeWarningCount++;
          }
        }
      }
      if (props[propName] == null) {
        if (isRequired) {
          if (props[propName] === null) {
            return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required ' + ('in `' + componentName + '`, but its value is `null`.'));
          }
          return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required in ' + ('`' + componentName + '`, but its value is `undefined`.'));
        }
        return null;
      } else {
        return validate(props, propName, componentName, location, propFullName);
      }
    }

    var chainedCheckType = checkType.bind(null, false);
    chainedCheckType.isRequired = checkType.bind(null, true);

    return chainedCheckType;
  }

  function createPrimitiveTypeChecker(expectedType) {
    function validate(props, propName, componentName, location, propFullName, secret) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== expectedType) {
        // `propValue` being instance of, say, date/regexp, pass the 'object'
        // check, but we can offer a more precise error message here rather than
        // 'of type `object`'.
        var preciseType = getPreciseType(propValue);

        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + preciseType + '` supplied to `' + componentName + '`, expected ') + ('`' + expectedType + '`.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createAnyTypeChecker() {
    return createChainableTypeChecker(emptyFunctionThatReturnsNull);
  }

  function createArrayOfTypeChecker(typeChecker) {
    function validate(props, propName, componentName, location, propFullName) {
      if (typeof typeChecker !== 'function') {
        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside arrayOf.');
      }
      var propValue = props[propName];
      if (!Array.isArray(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an array.'));
      }
      for (var i = 0; i < propValue.length; i++) {
        var error = typeChecker(propValue, i, componentName, location, propFullName + '[' + i + ']', ReactPropTypesSecret_1);
        if (error instanceof Error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createElementTypeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      if (!isValidElement(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected a single ReactElement.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createElementTypeTypeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      if (!reactIs.isValidElementType(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected a single ReactElement type.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createInstanceTypeChecker(expectedClass) {
    function validate(props, propName, componentName, location, propFullName) {
      if (!(props[propName] instanceof expectedClass)) {
        var expectedClassName = expectedClass.name || ANONYMOUS;
        var actualClassName = getClassName(props[propName]);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + actualClassName + '` supplied to `' + componentName + '`, expected ') + ('instance of `' + expectedClassName + '`.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createEnumTypeChecker(expectedValues) {
    if (!Array.isArray(expectedValues)) {
      if (process.env.NODE_ENV !== 'production') {
        if (arguments.length > 1) {
          printWarning$1(
            'Invalid arguments supplied to oneOf, expected an array, got ' + arguments.length + ' arguments. ' +
            'A common mistake is to write oneOf(x, y, z) instead of oneOf([x, y, z]).'
          );
        } else {
          printWarning$1('Invalid argument supplied to oneOf, expected an array.');
        }
      }
      return emptyFunctionThatReturnsNull;
    }

    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      for (var i = 0; i < expectedValues.length; i++) {
        if (is(propValue, expectedValues[i])) {
          return null;
        }
      }

      var valuesString = JSON.stringify(expectedValues, function replacer(key, value) {
        var type = getPreciseType(value);
        if (type === 'symbol') {
          return String(value);
        }
        return value;
      });
      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of value `' + String(propValue) + '` ' + ('supplied to `' + componentName + '`, expected one of ' + valuesString + '.'));
    }
    return createChainableTypeChecker(validate);
  }

  function createObjectOfTypeChecker(typeChecker) {
    function validate(props, propName, componentName, location, propFullName) {
      if (typeof typeChecker !== 'function') {
        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside objectOf.');
      }
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an object.'));
      }
      for (var key in propValue) {
        if (has$1(propValue, key)) {
          var error = typeChecker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
          if (error instanceof Error) {
            return error;
          }
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createUnionTypeChecker(arrayOfTypeCheckers) {
    if (!Array.isArray(arrayOfTypeCheckers)) {
      process.env.NODE_ENV !== 'production' ? printWarning$1('Invalid argument supplied to oneOfType, expected an instance of array.') : void 0;
      return emptyFunctionThatReturnsNull;
    }

    for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
      var checker = arrayOfTypeCheckers[i];
      if (typeof checker !== 'function') {
        printWarning$1(
          'Invalid argument supplied to oneOfType. Expected an array of check functions, but ' +
          'received ' + getPostfixForTypeWarning(checker) + ' at index ' + i + '.'
        );
        return emptyFunctionThatReturnsNull;
      }
    }

    function validate(props, propName, componentName, location, propFullName) {
      for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
        var checker = arrayOfTypeCheckers[i];
        if (checker(props, propName, componentName, location, propFullName, ReactPropTypesSecret_1) == null) {
          return null;
        }
      }

      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`.'));
    }
    return createChainableTypeChecker(validate);
  }

  function createNodeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      if (!isNode(props[propName])) {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`, expected a ReactNode.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createShapeTypeChecker(shapeTypes) {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
      }
      for (var key in shapeTypes) {
        var checker = shapeTypes[key];
        if (!checker) {
          continue;
        }
        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
        if (error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }

  function createStrictShapeTypeChecker(shapeTypes) {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
      }
      // We need to check all keys in case some are required but missing from
      // props.
      var allKeys = objectAssign({}, props[propName], shapeTypes);
      for (var key in allKeys) {
        var checker = shapeTypes[key];
        if (!checker) {
          return new PropTypeError(
            'Invalid ' + location + ' `' + propFullName + '` key `' + key + '` supplied to `' + componentName + '`.' +
            '\nBad object: ' + JSON.stringify(props[propName], null, '  ') +
            '\nValid keys: ' +  JSON.stringify(Object.keys(shapeTypes), null, '  ')
          );
        }
        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
        if (error) {
          return error;
        }
      }
      return null;
    }

    return createChainableTypeChecker(validate);
  }

  function isNode(propValue) {
    switch (typeof propValue) {
      case 'number':
      case 'string':
      case 'undefined':
        return true;
      case 'boolean':
        return !propValue;
      case 'object':
        if (Array.isArray(propValue)) {
          return propValue.every(isNode);
        }
        if (propValue === null || isValidElement(propValue)) {
          return true;
        }

        var iteratorFn = getIteratorFn(propValue);
        if (iteratorFn) {
          var iterator = iteratorFn.call(propValue);
          var step;
          if (iteratorFn !== propValue.entries) {
            while (!(step = iterator.next()).done) {
              if (!isNode(step.value)) {
                return false;
              }
            }
          } else {
            // Iterator will provide entry [k,v] tuples rather than values.
            while (!(step = iterator.next()).done) {
              var entry = step.value;
              if (entry) {
                if (!isNode(entry[1])) {
                  return false;
                }
              }
            }
          }
        } else {
          return false;
        }

        return true;
      default:
        return false;
    }
  }

  function isSymbol(propType, propValue) {
    // Native Symbol.
    if (propType === 'symbol') {
      return true;
    }

    // falsy value can't be a Symbol
    if (!propValue) {
      return false;
    }

    // 19.4.3.5 Symbol.prototype[@@toStringTag] === 'Symbol'
    if (propValue['@@toStringTag'] === 'Symbol') {
      return true;
    }

    // Fallback for non-spec compliant Symbols which are polyfilled.
    if (typeof Symbol === 'function' && propValue instanceof Symbol) {
      return true;
    }

    return false;
  }

  // Equivalent of `typeof` but with special handling for array and regexp.
  function getPropType(propValue) {
    var propType = typeof propValue;
    if (Array.isArray(propValue)) {
      return 'array';
    }
    if (propValue instanceof RegExp) {
      // Old webkits (at least until Android 4.0) return 'function' rather than
      // 'object' for typeof a RegExp. We'll normalize this here so that /bla/
      // passes PropTypes.object.
      return 'object';
    }
    if (isSymbol(propType, propValue)) {
      return 'symbol';
    }
    return propType;
  }

  // This handles more types than `getPropType`. Only used for error messages.
  // See `createPrimitiveTypeChecker`.
  function getPreciseType(propValue) {
    if (typeof propValue === 'undefined' || propValue === null) {
      return '' + propValue;
    }
    var propType = getPropType(propValue);
    if (propType === 'object') {
      if (propValue instanceof Date) {
        return 'date';
      } else if (propValue instanceof RegExp) {
        return 'regexp';
      }
    }
    return propType;
  }

  // Returns a string that is postfixed to a warning about an invalid type.
  // For example, "undefined" or "of type array"
  function getPostfixForTypeWarning(value) {
    var type = getPreciseType(value);
    switch (type) {
      case 'array':
      case 'object':
        return 'an ' + type;
      case 'boolean':
      case 'date':
      case 'regexp':
        return 'a ' + type;
      default:
        return type;
    }
  }

  // Returns class name of the object, if any.
  function getClassName(propValue) {
    if (!propValue.constructor || !propValue.constructor.name) {
      return ANONYMOUS;
    }
    return propValue.constructor.name;
  }

  ReactPropTypes.checkPropTypes = checkPropTypes_1;
  ReactPropTypes.resetWarningCache = checkPropTypes_1.resetWarningCache;
  ReactPropTypes.PropTypes = ReactPropTypes;

  return ReactPropTypes;
};

function emptyFunction() {}
function emptyFunctionWithReset() {}
emptyFunctionWithReset.resetWarningCache = emptyFunction;

var factoryWithThrowingShims = function() {
  function shim(props, propName, componentName, location, propFullName, secret) {
    if (secret === ReactPropTypesSecret_1) {
      // It is still safe when called from React.
      return;
    }
    var err = new Error(
      'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
      'Use PropTypes.checkPropTypes() to call them. ' +
      'Read more at http://fb.me/use-check-prop-types'
    );
    err.name = 'Invariant Violation';
    throw err;
  }  shim.isRequired = shim;
  function getShim() {
    return shim;
  }  // Important!
  // Keep this list in sync with production version in `./factoryWithTypeCheckers.js`.
  var ReactPropTypes = {
    array: shim,
    bool: shim,
    func: shim,
    number: shim,
    object: shim,
    string: shim,
    symbol: shim,

    any: shim,
    arrayOf: getShim,
    element: shim,
    elementType: shim,
    instanceOf: getShim,
    node: shim,
    objectOf: getShim,
    oneOf: getShim,
    oneOfType: getShim,
    shape: getShim,
    exact: getShim,

    checkPropTypes: emptyFunctionWithReset,
    resetWarningCache: emptyFunction
  };

  ReactPropTypes.PropTypes = ReactPropTypes;

  return ReactPropTypes;
};

var propTypes = createCommonjsModule(function (module) {
/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

if (process.env.NODE_ENV !== 'production') {
  var ReactIs = reactIs;

  // By explicitly using `prop-types` you are opting into new development behavior.
  // http://fb.me/prop-types-in-prod
  var throwOnDirectAccess = true;
  module.exports = factoryWithTypeCheckers(ReactIs.isElement, throwOnDirectAccess);
} else {
  // By explicitly using `prop-types` you are opting into new production behavior.
  // http://fb.me/prop-types-in-prod
  module.exports = factoryWithThrowingShims();
}
});

var lib = createCommonjsModule(function (module, exports) {

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();



var _react2 = _interopRequireDefault(React__default);



function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Script = function (_React$Component) {
  _inherits(Script, _React$Component);

  // A dictionary mapping script URL to a boolean value indicating if the script
  // has failed to load.


  // A dictionary mapping script URLs to a dictionary mapping
  // component key to component for all components that are waiting
  // for the script to load.
  function Script(props) {
    _classCallCheck(this, Script);

    var _this = _possibleConstructorReturn(this, (Script.__proto__ || Object.getPrototypeOf(Script)).call(this, props));

    _this.scriptLoaderId = 'id' + _this.constructor.idCount++; // eslint-disable-line space-unary-ops, no-plusplus
    return _this;
  }

  // A counter used to generate a unique id for each component that uses
  // ScriptLoaderMixin.


  // A dictionary mapping script URL to a boolean value indicating if the script
  // has already been loaded.


  _createClass(Script, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      var _props = this.props,
          onError = _props.onError,
          onLoad = _props.onLoad,
          url = _props.url;


      if (this.constructor.loadedScripts[url]) {
        onLoad();
        return;
      }

      if (this.constructor.erroredScripts[url]) {
        onError();
        return;
      }

      // If the script is loading, add the component to the script's observers
      // and return. Otherwise, initialize the script's observers with the component
      // and start loading the script.
      if (this.constructor.scriptObservers[url]) {
        this.constructor.scriptObservers[url][this.scriptLoaderId] = this.props;
        return;
      }

      this.constructor.scriptObservers[url] = _defineProperty({}, this.scriptLoaderId, this.props);

      this.createScript();
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      var url = this.props.url;

      var observers = this.constructor.scriptObservers[url];

      // If the component is waiting for the script to load, remove the
      // component from the script's observers before unmounting the component.
      if (observers) {
        delete observers[this.scriptLoaderId];
      }
    }
  }, {
    key: 'createScript',
    value: function createScript() {
      var _this2 = this;

      var _props2 = this.props,
          onCreate = _props2.onCreate,
          url = _props2.url,
          attributes = _props2.attributes;

      var script = document.createElement('script');

      onCreate();

      // add 'data-' or non standard attributes to the script tag
      if (attributes) {
        Object.keys(attributes).forEach(function (prop) {
          return script.setAttribute(prop, attributes[prop]);
        });
      }

      script.src = url;

      // default async to true if not set with custom attributes
      if (!script.hasAttribute('async')) {
        script.async = 1;
      }

      var callObserverFuncAndRemoveObserver = function callObserverFuncAndRemoveObserver(shouldRemoveObserver) {
        var observers = _this2.constructor.scriptObservers[url];
        Object.keys(observers).forEach(function (key) {
          if (shouldRemoveObserver(observers[key])) {
            delete _this2.constructor.scriptObservers[url][_this2.scriptLoaderId];
          }
        });
      };
      script.onload = function () {
        _this2.constructor.loadedScripts[url] = true;
        callObserverFuncAndRemoveObserver(function (observer) {
          observer.onLoad();
          return true;
        });
      };

      script.onerror = function () {
        _this2.constructor.erroredScripts[url] = true;
        callObserverFuncAndRemoveObserver(function (observer) {
          observer.onError();
          return true;
        });
      };

      document.body.appendChild(script);
    }
  }, {
    key: 'render',
    value: function render() {
      return null;
    }
  }]);

  return Script;
}(_react2.default.Component);

Script.propTypes = {
  attributes: propTypes.PropTypes.object, // eslint-disable-line react/forbid-prop-types
  onCreate: propTypes.PropTypes.func,
  onError: propTypes.PropTypes.func.isRequired,
  onLoad: propTypes.PropTypes.func.isRequired,
  url: propTypes.PropTypes.string.isRequired
};
Script.defaultProps = {
  attributes: {},
  onCreate: function onCreate() {},
  onError: function onError() {},
  onLoad: function onLoad() {} };
Script.scriptObservers = {};
Script.loadedScripts = {};
Script.erroredScripts = {};
Script.idCount = 0;
exports.default = Script;
module.exports = exports['default'];
});

var Script = unwrapExports(lib);

var NextUI = /** @class */ (function (_super) {
    __extends(NextUI, _super);
    function NextUI() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NextUI.prototype.shouldComponentUpdate = function (nextProps) {
        if (nextProps.style !== this.props.style)
            return true;
        return false; // Never rerender/re-load the script unless div style changes
    };
    NextUI.prototype.render = function () {
        return (React__default.createElement(React__default.Fragment, null,
            React__default.createElement(Script, { url: "https://cdn.jsdelivr.net/gh/jcace/next-bower@1.0.1/js/next.min.js", onError: function () {
                    return console.error("Error loading NEXT UI framework. Check your network connectivity.");
                }, onLoad: this.props.init }),
            React__default.createElement("div", { id: "nxContainer", style: this.props.style })));
    };
    return NextUI;
}(React__default.Component));

/**
 * NeXT UI React Hook
 * @param {topologyConfig, eventHandlers, topologyData, style, callback}
 * @returns { NextUI, nxApp } NextUI: component to render. Use {} syntax ie <>{NextUI}</>. nxApp:
 */
var useNextUi = function (_a) {
    var topologyConfig = _a.topologyConfig, eventHandlers = _a.eventHandlers, topologyData = _a.topologyData, style = _a.style, callback = _a.callback;
    var _b = React.useState(), nxApp = _b[0], setNxApp = _b[1];
    /**
     * Set topology data whenever it changes, or if nxApp is re-loaded for some reason.
     */
    React.useEffect(function () {
        if (!nxApp)
            return;
        nxApp.setData(cloneDeep_1(topologyData));
        mountEventHandlers();
    }, [topologyData, nxApp]);
    /**
     * Ensure eventHandlers are kept up to date if they change or their closure variables change
     */
    React.useEffect(function () {
        if (!nxApp)
            return;
        mountEventHandlers();
    }, [eventHandlers]);
    var mountEventHandlers = function () {
        if (!nxApp || !eventHandlers)
            return;
        Object.entries(eventHandlers).forEach(function (_a) {
            var event = _a[0], eventHandler = _a[1];
            nxApp.off(event); // We need to remove all event handlers first, because ".on" adds a NEW one, it doesn't REPLACE an existing one.
            nxApp.on(event, eventHandler);
        });
    };
    var initializeNxLibrary = function () {
        var tempApp = new window.nx.ui.Application();
        tempApp.container(document.getElementById("nxContainer"));
        // Instantiate a new nx Topology
        var nxTopologyApp = new window.nx.graphic.Topology(topologyConfig);
        nxTopologyApp.attach(tempApp); // Attach topology to div and display
        nxTopologyApp.data(topologyData); // Set the initial topology data
        // Save the instance into state
        setNxApp(nxTopologyApp);
        mountEventHandlers();
        if (callback) {
            callback(nxTopologyApp);
        }
    };
    return {
        NextUI: React__default.createElement(NextUI, { init: initializeNxLibrary, style: style }),
        nxApp: nxApp,
    };
};

// import NextContainer from "./NextContainer/NextContainer";

module.exports = useNextUi;
//# sourceMappingURL=index.js.map
